@@ -65,7 +65,7 @@ int
 afs_statfs(struct mount *mp, STATFS_TYPE *abp, CTX_TYPE ctx);
 #ifdef AFS_DARWIN80_ENV
 int
-afs_mount(struct mount *mp, vnode_t *devvp, user_addr_t data, vfs_context_t ctx)
+afs_mount(struct mount *mp, vnode_t devvp, user_addr_t data, vfs_context_t ctx)
 #else
 int
 afs_mount(struct mount *mp, char *path, caddr_t data, struct nameidata *ndp, CTX_TYPE ctx)
@@ -113,7 +113,10 @@ afs_mount(struct mount *mp, char *path, caddr_t data, struct nameidata *ndp, CTX
     memset(mnt_stat->f_mntfromname, 0, MNAMELEN);
 
     if (data == 0) {
-	strcpy(mnt_stat->f_mntfromname, "AFS");
+	if (strlcpy(mnt_stat->f_mntfromname, "AFS", MNAMELEN) >= MNAMELEN) {
+	    AFS_GUNLOCK();
+	    return ENAMETOOLONG;
+	}
 	/* null terminated string "AFS" will fit, just leave it be. */
 	vfs_setfsprivate(mp, NULL);
     } else {
@@ -125,7 +128,10 @@ afs_mount(struct mount *mp, char *path, caddr_t data, struct nameidata *ndp, CTX
 	memset(volName + size, 0, MNAMELEN - size);
 
 	if (volName[0] == 0) {
-	    strcpy(mnt_stat->f_mntfromname, "AFS");
+	    if (strlcpy(mnt_stat->f_mntfromname, "AFS", MNAMELEN) >= MNAMELEN) {
+		AFS_GUNLOCK();
+		return ENAMETOOLONG;
+	    }
 	    vfs_setfsprivate(mp, &afs_rootFid);
 	} else {
 	    struct cell *localcell = afs_GetPrimaryCell(READ_LOCK);
@@ -251,7 +257,7 @@ again:
 	    ? &afs_rootFid : (struct VenusFid *)mdata;
 
 	if (!(error = afs_InitReq(&treq, cr)) && !(error = afs_CheckInit())) {
-	    tvp = afs_GetVCache(rootFid, &treq, NULL, NULL);
+	    tvp = afs_GetVCache(rootFid, &treq);
 #ifdef AFS_DARWIN80_ENV
             if (tvp) {
 	        AFS_GUNLOCK();
@@ -525,7 +531,7 @@ afs_sysctl(int *name, u_int namelen, void *oldp, size_t *oldlenp,
     return ENOTSUP;
 }
 
-typedef (*PFI) ();
+typedef int (*PFI) ();
 extern int vfs_opv_numops;	/* The total number of defined vnode operations */
 extern struct vnodeopv_desc afs_vnodeop_opv_desc;
 int
