@@ -31,11 +31,24 @@
 # endif
 #endif
 
+#if defined(HAVE_LINUX_NO_SETPAGEERROR)
+static inline void
+ClearPageError(struct page *p)
+{
+    return;
+}
+static inline void
+SetPageError(struct page *p)
+{
+    return;
+}
+#endif
+
 #if !defined(HAVE_LINUX_KTHREAD_COMPLETE_AND_EXIT)
 # define kthread_complete_and_exit complete_and_exit
 #endif
 
-#if defined(STRUCT_DENTRY_OPERATIONS_HAS_D_AUTOMOUNT) && !defined(DCACHE_NEED_AUTOMOUNT)
+#if defined(STRUCT_DENTRY_OPERATIONS_HAS_D_AUTOMOUNT) && !defined(HAVE_DCACHE_NEED_AUTOMOUNT)
 # define DCACHE_NEED_AUTOMOUNT DMANAGED_AUTOMOUNT
 #endif
 
@@ -49,6 +62,10 @@ typedef struct path afs_linux_path_t;
 # define d_alias d_u.d_alias
 #endif
 
+#if defined(STRUCT_DENTRY_HAS_D_U_D_CHILD)
+# define d_child d_u.d_child
+#endif
+
 #if defined(STRUCT_FILE_HAS_F_PATH)
 # if !defined(f_dentry)
 #  define f_dentry f_path.dentry
@@ -106,31 +123,28 @@ afs_posix_test_lock(struct file *fp, struct file_lock *flp) {
 #endif
 }
 
-#ifdef DCACHE_NFSFS_RENAMED
 static inline void
-afs_linux_clear_nfsfs_renamed(struct dentry *dp) {
+afs_linux_clear_nfsfs_renamed(struct dentry *dp)
+{
     spin_lock(&dp->d_lock);
     dp->d_flags &= ~DCACHE_NFSFS_RENAMED;
     spin_unlock(&dp->d_lock);
 }
 
 static inline void
-afs_linux_set_nfsfs_renamed(struct dentry *dp) {
+afs_linux_set_nfsfs_renamed(struct dentry *dp)
+{
     spin_lock(&dp->d_lock);
     dp->d_flags |= DCACHE_NFSFS_RENAMED;
     spin_unlock(&dp->d_lock);
 }
 
 static inline int
-afs_linux_nfsfs_renamed(struct dentry *dp) {
+afs_linux_nfsfs_renamed(struct dentry *dp)
+{
     return dp->d_flags & DCACHE_NFSFS_RENAMED;
 }
 
-#else
-static inline void afs_linux_clear_nfsfs_renamed(void) { return; }
-static inline void afs_linux_set_nfsfs_renamed(void) { return; }
-#endif
-
 #ifndef HAVE_LINUX_HLIST_UNHASHED
 static void
 hlist_unhashed(const struct hlist_node *h) {
@@ -144,7 +158,8 @@ hlist_unhashed(const struct hlist_node *h) {
 
 #if defined(STRUCT_ADDRESS_SPACE_OPERATIONS_HAS_WRITE_BEGIN) && \
     !defined(HAVE_LINUX_GRAB_CACHE_PAGE_WRITE_BEGIN_WITHFLAGS) && \
-    !defined(HAVE_LINUX_GRAB_CACHE_PAGE_WRITE_BEGIN_NOFLAGS)
+    !defined(HAVE_LINUX_GRAB_CACHE_PAGE_WRITE_BEGIN_NOFLAGS) && \
+    !defined(HAVE_LINUX_FILEMAP_GET_FOLIO)
 static inline struct page *
 grab_cache_page_write_begin(struct address_space *mapping, pgoff_t index,
 			    unsigned int flags) {
@@ -292,6 +307,18 @@ afs_linux_cred_is_current(afs_ucred_t *cred)
 }
 #endif
 
+/* Folio / Page wrappers */
+
+static inline pgoff_t
+afs_page_index(struct page *p)
+{
+#if defined(STRUCT_PAGE_HAS___FOLIO_INDEX)
+    return p->__folio_index;
+#else
+    return p->index;
+#endif
+}
+
 #ifndef HAVE_LINUX_PAGE_OFFSET
 static inline loff_t
 page_offset(struct page *pp)
@@ -818,4 +845,81 @@ afs_setattr_prepare(struct dentry *dp, struct iattr *newattrs)
 
 #endif /* D_ALIAS_IS_HLIST */
 
+static inline void
+afs_page_wait_locked(struct page *p)
+{
+#if defined(HAVE_LINUX_FOLIO_WAIT_LOCKED)
+    return folio_wait_locked(page_folio(p));
+#else
+    return wait_on_page_locked(p);
+#endif
+}
+static inline void
+afs_put_page(struct page *p)
+{
+#if defined(HAVE_LINUX_FOLIO_WAIT_LOCKED)
+    return folio_put(page_folio(p));
+#else
+    return put_page(p);
+#endif
+}
+
+/*
+ * Test to see if the folio associated with a page is locked.
+ * Compatibility function for when the code is dealing with pages and is
+ * referencing the head page of a folio instead of referencing the folio directly.
+ */
+static inline int
+afs_FolioLocked(struct page *page)
+{
+#if defined(HAVE_LINUX_READAHEAD_FOLIO)
+    return folio_test_locked(page_folio(page));
+#else
+    return PageLocked(page);
+#endif
+}
+
+/*
+ * Unlock the folio associated with a page.
+ * Compatibility function for when the code is dealing with pages and is
+ * referencing the head page of a folio instead of referencing the folio directly.
+ */
+static inline void
+afs_unlock_folio(struct page *page)
+{
+#if defined(HAVE_LINUX_READAHEAD_FOLIO)
+    folio_unlock(page_folio(page));
+#else
+    unlock_page(page);
+#endif
+}
+
+#if defined(STRUCT_ADDRESS_SPACE_OPERATIONS_HAS_READAHEAD)
+static inline struct page *
+afs_readahead_folio(struct readahead_control *rac)
+{
+# if defined(HAVE_LINUX_READAHEAD_FOLIO)
+    struct folio *folio;
+
+    folio = __readahead_folio(rac);
+    if (folio == NULL) {
+	return NULL;
+    }
+    return folio_page(folio, 0);
+# else
+    return readahead_page(rac);
+# endif
+}
+#endif
+
+static inline struct dentry *
+afs_lookup_noperm(char *name, struct dentry *dp)
+{
+#if defined(HAVE_LINUX_LOOKUP_NOPERM)
+    return lookup_noperm(&QSTR(name), dp);
+#else
+    return lookup_one_len(name, dp, strlen(name));
+#endif
+}
+
 #endif /* AFS_LINUX_OSI_COMPAT_H */
