@@ -424,7 +424,7 @@ static int UnEvalFakeStat(struct vrequest *areq, struct vcache **vcpp)
     tfid = tvp->mtpoint;
     afs_PutVolume(tvp, READ_LOCK);
 
-    tvc = afs_GetVCache(&tfid, areq, NULL, NULL);
+    tvc = afs_GetVCache(&tfid, areq);
     if (!tvc) {
 #ifdef OSI_EXPORT_DEBUG
 	printk("afs: UnEvalFakeStat(0x%08x/%d/%d.%d): GetVCache(0x%08x/%d/%d.%d) failed\n",
@@ -486,7 +486,7 @@ static struct dentry *get_dentry_from_fid(cred_t *credp, struct VenusFid *afid)
 	afs_DestroyAttr(vattr);
 	return ERR_PTR(-afs_CheckCode(code, NULL, 101));
     }
-    vcp = afs_GetVCache(afid, treq, NULL, NULL);
+    vcp = afs_GetVCache(afid, treq);
     if (vcp == NULL) {
 #ifdef OSI_EXPORT_DEBUG
 	printk("afs: get_dentry_from_fid(0x%08x/%d/%d.%d): no vcache\n",
@@ -689,7 +689,7 @@ static int afs_export_get_name(struct dentry *parent, char *name,
 	       data.fid.Cell,      data.fid.Fid.Volume,
 	       data.fid.Fid.Vnode, data.fid.Fid.Unique);
 #endif
-	vcp = afs_GetVCache(&data.fid, treq, NULL, NULL);
+	vcp = afs_GetVCache(&data.fid, treq);
 	if (vcp) {
 	    ObtainReadLock(&vcp->lock);
 	    if (strlen(vcp->linkData + 1) <= NAME_MAX)
