@@ -108,7 +108,7 @@ NONINFRINGEMENT.
 /* from /usr/src/sys/kern/vfs_subr.c */
 extern void insmntque(struct vnode *, struct mount *);
 
-extern int sys_lkmnosys(), afs_xioctl(), Afs_xsetgroups();
+extern int sys_lkmnosys(), Afs_xsetgroups();
 
 static int lkmid = -1;
 static int afs_badcall(struct proc *p, void *xx, register_t * yy);
@@ -343,7 +343,7 @@ afs_root(struct mount *mp, struct vnode **vpp)
     AFS_GLOCK();
     if (!(code = afs_InitReq(&treq, osi_curcred()))
 	&& !(code = afs_CheckInit())) {
-	tvp = afs_GetVCache(&afs_rootFid, &treq, NULL, NULL);
+	tvp = afs_GetVCache(&afs_rootFid, &treq);
 	if (tvp) {
 	    /* There is really no reason to over-hold this bugger--it's held
 	     * by the root filesystem reference. */
