@@ -179,7 +179,6 @@ typedef unsigned int fsblkcnt_t;
 
 #ifdef UKERNEL
 
-#undef socket
 #undef flock
 
 #if defined(AFS_USR_DARWIN_ENV) || defined(AFS_USR_FBSD_ENV)
@@ -202,14 +201,11 @@ typedef unsigned int fsblkcnt_t;
 #define statfs			usr_statfs
 #define file			usr_file
 #define dirent			usr_dirent
-#define flock			usr_flock
 #define fid			usr_fid
 #define sysent			usr_sysent
 #define ifaddr                  usr_ifaddr
 #define ifnet                   usr_ifnet
 #define in_ifaddr		usr_in_ifaddr
-#undef socket
-#define socket			usr_socket
 #define crget			usr_crget
 #define crcopy			usr_crcopy
 #define crhold			usr_crhold
@@ -1099,17 +1095,11 @@ struct usr_buf {
     struct usr_vnode *b_vp;
 };
 
-struct usr_socket {
-    int sock;
-    short port;
-};
-
 #define NDIRSIZ_LEN(len) \
 ((sizeof (struct usr_dirent)+4 - (MAXNAMLEN+1)) + (((len)+1 + 3) &~ 3))
 
 struct vcache;
 #define afs_ucred_t struct usr_ucred
-#define AFS_FLOCK       flock
 
 
 struct usr_vnodeops {
@@ -1144,7 +1134,7 @@ struct usr_vnodeops {
     int (*vn_strategy) (void);
     int (*vn_bread) (void);
     int (*vn_brelse) (void);
-    int (*vn_lockctl) (struct vcache *, struct AFS_FLOCK *, int,
+    int (*vn_lockctl) (struct vcache *, struct usr_flock *, int,
 		       afs_ucred_t *);
     int (*vn_fid) (struct vcache *avc, struct fid **);
 };
