@@ -178,10 +178,10 @@ afs_create(OSI_VC_DECL(adp), char *aname, struct vattr *attrs,
 	    newFid.Fid.Volume = adp->f.fid.Fid.Volume;
 	    tvc = NULL;
 	    if (newFid.Fid.Unique == 0) {
-		tvc = afs_LookupVCache(&newFid, treq, NULL, adp, aname);
+		tvc = afs_LookupVCache(&newFid, treq, adp, aname);
 	    }
 	    if (!tvc)		/* lookup failed or wasn't called */
-		tvc = afs_GetVCache(&newFid, treq, NULL, NULL);
+		tvc = afs_GetVCache(&newFid, treq);
 
 	    if (tvc) {
 		/* if the thing exists, we need the right access to open it.
@@ -433,7 +433,7 @@ afs_create(OSI_VC_DECL(adp), char *aname, struct vattr *attrs,
      * freeing of the vnode will change evenZaps.  Don't need to update the VLRU
      * queue, since the find will only succeed in the event of a create race, and 
      * then the vcache will be at the front of the VLRU queue anyway...  */
-    if (!(tvc = afs_FindVCache(&newFid, 0, DO_STATS))) {
+    if (!(tvc = afs_FindVCache(&newFid, DO_STATS))) {
 	tvc = afs_NewVCache(&newFid, hostp);
 	if (tvc) {
 	    int finalCBs;
