@@ -327,6 +327,112 @@ afs_InitFakeStat(struct afs_fakestat_state *state)
     state->need_release = 0;
 }
 
+#ifdef AFS_DARWIN80_ENV
+/*
+ * Finalize a volume root vcache, after resolving a mountpoint.
+ *
+ * When we create a vcache on macOS, we need to fill in some macOS-specific
+ * info that is usually done by calling afs_darwin_finalizevnode() in the
+ * syscall that creates the vcache (e.g., creat() or a lookup). But when using
+ * fakestat, we resolve a mountpoint into the corresponding volume root vcache
+ * internally, and so we may create a vcache for the root dir, but we don't
+ * have the arguments of a syscall to provide to afs_darwin_finalizevnode().
+ *
+ * So after we have resolved a mountpoint to a root vcache, in this function we
+ * try to finalize the root vcache, and figure out the parent dir and 'name' to
+ * give to macOS for it. If we don't provide a parent for the vcache, macOS may
+ * throw bogus ENOENT errors in the future when trying to use the dir.
+ *
+ * \param a_rootvp  vcache we are finalizing (vcache for a volume root). If an
+ *		    error is returned, we free the given reference before
+ *		    returning, and set this to NULL. On success, this is
+ *		    vnode_ref()d.
+ * \param mvc   vcache of the mtpt pointing to root_vp
+ * \param areq	vrequest
+ * \param canblock  1 if we can hit the net, 0 otherwise
+ *
+ * \returns 0 on success, or error code otherwise
+ */
+static int
+afs_darwin_finalize_volroot(struct vcache **a_rootvp, struct vcache *mvc,
+			    struct vrequest *areq, int canblock)
+{
+    struct vcache *root_vp = *a_rootvp;
+    struct vcache *parent = NULL;
+    const char *rname = NULL;
+    int code, flags;
+
+    if (root_vp->mvstat != AFS_MVSTAT_ROOT) {
+	code = EINVAL;
+	goto done_locked;
+    }
+    root_vp->f.m.Type = VDIR;
+
+    if (root_vp->mvid.parent != NULL) {
+	if (!canblock) {
+	    ObtainReadLock(&afs_xvcache);
+	    parent = afs_FindVCache(root_vp->mvid.parent, 0);
+	    ReleaseReadLock(&afs_xvcache);
+	} else {
+	    parent = afs_GetVCache(root_vp->mvid.parent, areq);
+	}
+    }
+
+    AFS_GUNLOCK();
+
+    code = afs_darwin_finalizevnode(root_vp, NULL, NULL, 0, 0);
+    if (code != 0) {
+	/* afs_darwin_finalizevnode releases the ref to root_vp on error. */
+	root_vp = NULL;
+	goto done;
+    }
+
+    vnode_ref(AFSTOV(root_vp));
+
+    if (vnode_isvroot(AFSTOV(root_vp))) {
+	goto done;
+    }
+
+    if (parent == NULL) {
+	/* Don't let the caller use root_vp if we can't set a parent. */
+	struct vnode *vfs_parent = vnode_getparent(AFSTOV(root_vp));
+	if (vfs_parent != NULL) {
+	    /* ...but if it already has a parent, that's okay. */
+	    vnode_put(vfs_parent);
+	    goto done;
+	}
+	code = EIO;
+	goto done;
+    }
+
+    flags = VNODE_UPDATE_PARENT | VNODE_UPDATE_CACHE;
+    rname = vnode_getname(AFSTOV(mvc));
+    if (rname != NULL) {
+	flags |= VNODE_UPDATE_NAME;
+    }
+
+    vnode_update_identity(AFSTOV(root_vp), AFSTOV(parent), rname, 0, 0, flags);
+
+    if (rname != NULL) {
+	vnode_putname(rname);
+    }
+
+ done:
+    AFS_GLOCK();
+
+ done_locked:
+    if (parent != NULL) {
+	afs_PutVCache(parent);
+    }
+    if (root_vp != NULL && code != 0) {
+	afs_PutVCache(root_vp);
+	root_vp = NULL;
+    }
+    *a_rootvp = root_vp;
+    return code;
+}
+#endif /* AFS_DARWIN80_ENV */
+
 /*
  * afs_EvalFakeStat_int
  *
@@ -339,7 +445,7 @@ static int
 afs_EvalFakeStat_int(struct vcache **avcp, struct afs_fakestat_state *state,
 		     struct vrequest *areq, int canblock)
 {
-    struct vcache *tvc, *root_vp;
+    struct vcache *tvc;
     struct volume *tvolp = NULL;
     int code = 0;
 
@@ -372,34 +478,18 @@ afs_EvalFakeStat_int(struct vcache **avcp, struct afs_fakestat_state *state,
 	}
     }
     if (tvc->mvid.target_root && (tvc->f.states & CMValid)) {
+	struct vcache *root_vp;
 	if (!canblock) {
-	    afs_int32 retry;
-
-	    do {
-		retry = 0;
-		ObtainReadLock(&afs_xvcache);
-		root_vp = afs_FindVCache(tvc->mvid.target_root, &retry, 0);
-		if (root_vp && retry) {
-		    ReleaseReadLock(&afs_xvcache);
-		    afs_PutVCache(root_vp);
-		}
-	    } while (root_vp && retry);
+	    ObtainReadLock(&afs_xvcache);
+	    root_vp = afs_FindVCache(tvc->mvid.target_root, 0);
 	    ReleaseReadLock(&afs_xvcache);
 	} else {
-	    root_vp = afs_GetVCache(tvc->mvid.target_root, areq, NULL, NULL);
+	    root_vp = afs_GetVCache(tvc->mvid.target_root, areq);
 	}
 	if (!root_vp) {
 	    code = canblock ? EIO : 0;
 	    goto done;
 	}
-#ifdef AFS_DARWIN80_ENV
-        root_vp->f.m.Type = VDIR;
-        AFS_GUNLOCK();
-        code = afs_darwin_finalizevnode(root_vp, NULL, NULL, 0, 0);
-        AFS_GLOCK();
-        if (code) goto done;
-        vnode_ref(AFSTOV(root_vp));
-#endif
 	if (tvolp && !afs_InReadDir(root_vp)) {
 	    /* Is this always kosher?  Perhaps we should instead use
 	     * NBObtainWriteLock to avoid potential deadlock.
@@ -410,6 +500,13 @@ afs_EvalFakeStat_int(struct vcache **avcp, struct afs_fakestat_state *state,
 	    *root_vp->mvid.parent = tvolp->dotdot;
 	    ReleaseWriteLock(&root_vp->lock);
 	}
+#ifdef AFS_DARWIN80_ENV
+	code = afs_darwin_finalize_volroot(&root_vp, tvc, areq, canblock);
+	if (code != 0) {
+	    code = canblock ? code : 0;
+	    goto done;
+	}
+#endif
 	state->need_release = 1;
 	state->root_vp = root_vp;
 	*avcp = root_vp;
@@ -724,7 +821,7 @@ afs_DoBulkStat(struct vcache *adp, long dirCookie, struct vrequest *areqp)
     int i;
     struct VenusFid afid;	/* file ID we are using now */
     struct VenusFid tfid;	/* another temp. file ID */
-    afs_int32 retry;		/* handle low-level SGI MP race conditions */
+    afs_int32 retry;		/* handle low-level VFS race conditions */
     long volStates;		/* flags from vol structure */
     struct volume *volp = 0;	/* volume ptr */
     struct VenusFid dotdot = {0, {0, 0, 0}};
@@ -870,15 +967,8 @@ afs_DoBulkStat(struct vcache *adp, long dirCookie, struct vrequest *areqp)
 	    tfid.Fid.Volume = adp->f.fid.Fid.Volume;
 	    tfid.Fid.Vnode = ntohl(dirEntryp->fid.vnode);
 	    tfid.Fid.Unique = ntohl(dirEntryp->fid.vunique);
-	    do {
-		retry = 0;
-		ObtainSharedLock(&afs_xvcache, 130);
-		tvcp = afs_FindVCache(&tfid, &retry, IS_SLOCK /* no stats | LRU */ );
-		if (tvcp && retry) {
-		    ReleaseSharedLock(&afs_xvcache);
-		    afs_PutVCache(tvcp);
-		}
-	    } while (tvcp && retry);
+	    ObtainSharedLock(&afs_xvcache, 130);
+	    tvcp = afs_FindVCache(&tfid, IS_SLOCK /* no stats | LRU */ );
 	    if (!tvcp) {	/* otherwise, create manually */
 		UpgradeSToWLock(&afs_xvcache, 129);
 		tvcp = afs_NewBulkVCache(&tfid, hostp, statSeqNo);
@@ -1009,12 +1099,9 @@ afs_DoBulkStat(struct vcache *adp, long dirCookie, struct vrequest *areqp)
 		afid.Fid.Vnode = fidsp[i].Vnode;
 		afid.Fid.Unique = fidsp[i].Unique;
 
-		do {
-		    retry = 0;
-		    ObtainReadLock(&afs_xvcache);
-		    tvcp = afs_FindVCache(&afid, &retry, 0 /* !stats&!lru */);
-		    ReleaseReadLock(&afs_xvcache);
-		} while (tvcp && retry);
+		ObtainReadLock(&afs_xvcache);
+		tvcp = afs_FindVCache(&afid, 0 /* !stats&!lru */);
+		ReleaseReadLock(&afs_xvcache);
 
 		if (!tvcp) {
 		    continue;
@@ -1170,12 +1257,10 @@ afs_DoBulkStat(struct vcache *adp, long dirCookie, struct vrequest *areqp)
 	afid.Fid.Volume = adp->f.fid.Fid.Volume;
 	afid.Fid.Vnode = fidsp[i].Vnode;
 	afid.Fid.Unique = fidsp[i].Unique;
-	do {
-	    retry = 0;
-	    ObtainReadLock(&afs_xvcache);
-	    tvcp = afs_FindVCache(&afid, &retry, 0/* !stats&!lru */);
-	    ReleaseReadLock(&afs_xvcache);
-	} while (tvcp && retry);
+
+	ObtainReadLock(&afs_xvcache);
+	tvcp = afs_FindVCache(&afid, 0/* !stats&!lru */);
+	ReleaseReadLock(&afs_xvcache);
 
 	/* The entry may no longer exist */
 	if (tvcp == NULL) {
@@ -1349,12 +1434,10 @@ afs_DoBulkStat(struct vcache *adp, long dirCookie, struct vrequest *areqp)
 	afid.Fid.Volume = adp->f.fid.Fid.Volume;
 	afid.Fid.Vnode = fidsp[i].Vnode;
 	afid.Fid.Unique = fidsp[i].Unique;
-	do {
-	    retry = 0;
-	    ObtainReadLock(&afs_xvcache);
-	    tvcp = afs_FindVCache(&afid, &retry, 0 /* !stats&!lru */);
-	    ReleaseReadLock(&afs_xvcache);
-	} while (tvcp && retry);
+
+	ObtainReadLock(&afs_xvcache);
+	tvcp = afs_FindVCache(&afid, 0 /* !stats&!lru */);
+	ReleaseReadLock(&afs_xvcache);
 	if (tvcp != NULL) {
 	    if ((tvcp->f.states & CBulkFetching)
 		&& (tvcp->f.m.Length == statSeqNo)) {
@@ -1526,7 +1609,7 @@ afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, afs_ucred_t *acr
 	}
 	/* otherwise we have the fid here, so we use it */
 	/*printf("Getting vcache\n");*/
-	tvc = afs_GetVCache(adp->mvid.parent, treq, NULL, NULL);
+	tvc = afs_GetVCache(adp->mvid.parent, treq);
 	afs_Trace3(afs_iclSetp, CM_TRACE_GETVCDOTDOT, ICL_TYPE_FID, adp->mvid.parent,
 		   ICL_TYPE_POINTER, tvc, ICL_TYPE_INT32, code);
 	*avcp = tvc;
@@ -1630,7 +1713,7 @@ afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, afs_ucred_t *acr
 	    tfid.Fid.Vnode = VNUM_FROM_TYPEID(VN_TYPE_MOUNT, cellidx << 2);
 	    tfid.Fid.Unique = volid;
 	}
-	*avcp = tvc = afs_GetVCache(&tfid, treq, NULL, NULL);
+	*avcp = tvc = afs_GetVCache(&tfid, treq);
 	code = (tvc ? 0 : EIO);
 	hit = 1;
 	goto done;
@@ -1646,7 +1729,7 @@ afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, afs_ucred_t *acr
 	struct VenusFid tfid;
 
 	afs_GetDynrootMountFid(&tfid);
-	*avcp = tvc = afs_GetVCache(&tfid, treq, NULL, NULL);
+	*avcp = tvc = afs_GetVCache(&tfid, treq);
 	code = 0;
 	hit = 1;
 	goto done;
@@ -1820,16 +1903,12 @@ afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, afs_ucred_t *acr
 	 * dirCookie tells us where to start prefetching from.
 	 */
 	if (afs_ShouldTryBulkStat(adp)) {
-	    afs_int32 retry;
 	    /* if the entry is not in the cache, or is in the cache,
 	     * but hasn't been statd, then do a bulk stat operation.
 	     */
-	    do {
-		retry = 0;
-		ObtainReadLock(&afs_xvcache);
-		tvc = afs_FindVCache(&tfid, &retry, 0 /* !stats,!lru */ );
-		ReleaseReadLock(&afs_xvcache);
-	    } while (tvc && retry);
+	    ObtainReadLock(&afs_xvcache);
+	    tvc = afs_FindVCache(&tfid, 0 /* !stats,!lru */ );
+	    ReleaseReadLock(&afs_xvcache);
 
 	    if (!tvc || !(tvc->f.states & CStatd))
 		bulkcode = afs_DoBulkStat(adp, dirCookie, treq);
@@ -1854,12 +1933,11 @@ afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, afs_ucred_t *acr
 	 * the file has not yet been looked up.
 	 */
 	if (!tvc) {
-	    afs_int32 cached = 0;
 	    if (!tfid.Fid.Unique && (adp->f.states & CForeign)) {
-		tvc = afs_LookupVCache(&tfid, treq, &cached, adp, tname);
+		tvc = afs_LookupVCache(&tfid, treq, adp, tname);
 	    }
 	    if (!tvc && !bulkcode) {	/* lookup failed or wasn't called */
-		tvc = afs_GetVCache(&tfid, treq, &cached, NULL);
+		tvc = afs_GetVCache(&tfid, treq);
 	    }
 	}			/* if !tvc */
     }				/* sub-block just to reduce stack usage */
@@ -1919,9 +1997,9 @@ afs_lookup(OSI_VC_DECL(adp), char *aname, struct vcache **avcp, afs_ucred_t *acr
 		    if (tvolp && (tvolp->states & VForeign)) {
 			/* XXXX tvolp has ref cnt on but not locked! XXX */
 			tvc =
-			    afs_GetRootVCache(tvc->mvid.target_root, treq, NULL, tvolp);
+			    afs_GetRootVCache(tvc->mvid.target_root, treq, tvolp);
 		    } else {
-			tvc = afs_GetVCache(tvc->mvid.target_root, treq, NULL, NULL);
+			tvc = afs_GetVCache(tvc->mvid.target_root, treq);
 		    }
 		    afs_PutVCache(uvc);	/* we're done with it */
 
