@@ -19,6 +19,8 @@
 
 #include "afs/sysincludes.h"	/*Standard vendor system headers */
 #include "afsincludes.h"	/*AFS-based standard headers */
+#define FSINT_COMMON_XG
+#include "afs/afscbint.h"
 #include "afs/afs_stats.h"	/*Cache Manager stats */
 #include "afs/opr.h"
 #include "afs/afs_args.h"
@@ -1472,71 +1474,6 @@ SRXAFSCB_GetCacheConfig(struct rx_call *a_call, afs_uint32 callerVersion,
     return 0;
 }
 
-/*------------------------------------------------------------------------
- * EXPORTED SRXAFSCB_FetchData
- *
- * Description:
- *      Routine to do third party move from a remioserver to the original
- *      issuer of an ArchiveData request. Presently supported only by the
- *      "fs" command, not by the AFS client.
- *
- * Arguments:
- *      rxcall:        Ptr to Rx call on which this request came in.
- *      Fid:           pointer to AFSFid structure.
- *      Fd:            File descriptor inside fs command.
- *      Position:      Offset in the file.
- *      Length:        Data length to transfer.
- *      TotalLength:   Pointer to total file length field
- *
- * Returns:
- *      0 on success
- *
- * Environment:
- *      Nothing interesting.
- *
- * Side Effects:
- *------------------------------------------------------------------------*/
-int
-SRXAFSCB_FetchData(struct rx_call *rxcall, struct AFSFid *Fid, afs_int32 Fd,
-		   afs_int64 Position, afs_int64 Length,
-		   afs_int64 * TotalLength)
-{
-    return ENOSYS;
-}
-
-/*------------------------------------------------------------------------
- * EXPORTED SRXAFSCB_StoreData
- *
- * Description:
- *      Routine to do third party move from a remioserver to the original
- *      issuer of a RetrieveData request. Presently supported only by the
- *      "fs" command, not by the AFS client.
- *
- * Arguments:
- *      rxcall:        Ptr to Rx call on which this request came in.
- *      Fid:           pointer to AFSFid structure.
- *      Fd:            File descriptor inside fs command.
- *      Position:      Offset in the file.
- *      Length:        Data length to transfer.
- *      TotalLength:   Pointer to total file length field
- *
- * Returns:
- *      0 on success
- *
- * Environment:
- *      Nothing interesting.
- *
- * Side Effects:
- *      As advertised.
- *------------------------------------------------------------------------*/
-int
-SRXAFSCB_StoreData(struct rx_call *rxcall, struct AFSFid *Fid, afs_int32 Fd,
-		   afs_int64 Position, afs_int64 Length,
-		   afs_int64 * TotalLength)
-{
-    return ENOSYS;
-}
-
 /*------------------------------------------------------------------------
  * EXPORTED SRXAFSCB_GetCellByNum
  *
@@ -1636,14 +1573,3 @@ SRXAFSCB_TellMeAboutYourself(struct rx_call *a_call,
 
     return code;
 }
-
-
-int
-SRXAFSCB_GetDE(struct rx_call *a_call, afs_int32 a_index, afs_int32 *addr,
-	       afs_int32 *inode, afs_int32 *flags, afs_int32 *time,
-	       char ** fileName)
-{ /*SRXAFSCB_GetDE*/
-    int code = 0;				/*Return code*/
-    return(code);
-
-} /*SRXAFSCB_GetDE*/
