@@ -413,12 +413,8 @@ afs_InitCacheInfo(char *afile)
 # endif /* AFS_SUN5_ENV */
 
 # if defined(AFS_SGI_ENV)
-#  ifdef AFS_SGI65_ENV
 	VFS_STATVFS(filevp->v_vfsp, &st, NULL, code);
 	if (!code)
-#  else
-	if (!VFS_STATFS(filevp->v_vfsp, &st, NULL))
-#  endif /* AFS_SGI65_ENV */
 # elif defined(AFS_SUN5_ENV) || defined(AFS_HPUX100_ENV)
 	if (!VFS_STATVFS(filevp->v_vfsp, &st))
 # elif defined(AFS_AIX41_ENV)
@@ -547,7 +543,7 @@ afs_ResourceInit(int preallocs)
 	    osi_Assert(afs_sysnamelist[i] != NULL);
 	}
 	afs_sysname = afs_sysnamelist[0];
-	strcpy(afs_sysname, SYS_NAME);
+	osi_Assert(strlcpy(afs_sysname, SYS_NAME, MAXSYSNAME) < MAXSYSNAME);
 	afs_sysnamecount = 1;
 	afs_sysnamegen++;
     }
