@@ -180,7 +180,7 @@ afs_StoreAllSegments(struct vcache *avc, struct vrequest *areq,
     dcList = osi_AllocLargeSpace(AFS_LRALLOCSIZ);
     afs_Trace2(afs_iclSetp, CM_TRACE_STOREALL, ICL_TYPE_POINTER, avc,
 	       ICL_TYPE_OFFSET, ICL_HANDLE_OFFSET(avc->f.m.Length));
-#if !defined(AFS_AIX32_ENV) && !defined(AFS_SGI65_ENV)
+#if !defined(AFS_AIX32_ENV) && !defined(AFS_SGI_ENV)
     /* In the aix vm implementation we need to do the vm_writep even
      * on the memcache case since that's we adjust the file's size
      * and finish flushing partial vm pages.
@@ -188,7 +188,7 @@ afs_StoreAllSegments(struct vcache *avc, struct vrequest *areq,
     if ((cacheDiskType != AFS_FCACHE_TYPE_MEM) ||
 	(sync & AFS_VMSYNC_INVAL) || (sync & AFS_VMSYNC) ||
 	(sync & AFS_LASTSTORE))
-#endif /* !AFS_AIX32_ENV && !AFS_SGI65_ENV */
+#endif /* !AFS_AIX32_ENV && !AFS_SGI_ENV */
     {
 	/* If we're not diskless, reading a file may stress the VM
 	 * system enough to cause a pageout, and this vnode would be
@@ -496,6 +496,17 @@ afs_StoreAllSegments(struct vcache *avc, struct vrequest *areq,
 
 }				/*afs_StoreAllSegments (new 03/02/94) */
 
+/*!
+ * Attempt to invalidate all chunks for a given file.
+ *
+ * \pre avc->lock is write-locked
+ * \pre afs_xdcache is not held
+ *
+ * \param   avc	vcache to invalidate segments for
+ * \return  errno-style error codes. when an error is returned, the caller must
+ *	    retry the invalidation until successful (see comments in
+ *	    afs_InvalidateAllSegments)
+ */
 int
 afs_InvalidateAllSegments_once(struct vcache *avc)
 {
@@ -503,19 +514,21 @@ afs_InvalidateAllSegments_once(struct vcache *avc)
     afs_int32 hash;
     afs_int32 index;
     struct dcache **dcList = NULL;
-    int i, dcListMax, dcListCount;
+    int i, dcListMax, dcListCount = 0;
 
     AFS_STATCNT(afs_InvalidateAllSegments);
     afs_Trace2(afs_iclSetp, CM_TRACE_INVALL, ICL_TYPE_POINTER, avc,
 	       ICL_TYPE_OFFSET, ICL_HANDLE_OFFSET(avc->f.m.Length));
+
+    osi_Assert(WriteLocked(&avc->lock));
+
     hash = DVHash(&avc->f.fid);
     avc->f.truncPos = AFS_NOTRUNC;	/* don't truncate later */
     avc->f.states &= ~CExtendedFile;	/* not any more */
     afs_StaleVCacheFlags(avc, 0, CDirty);
     /* Blow away pages; for now, only for Solaris */
 #if	(defined(AFS_SUN5_ENV))
-    if (WriteLocked(&avc->lock))
-	osi_ReleaseVM(avc, (afs_ucred_t *)0);
+    osi_ReleaseVM(avc, (afs_ucred_t *)0);
 #endif
     /*
      * Block out others from screwing with this table; is a read lock
@@ -539,7 +552,6 @@ afs_InvalidateAllSegments_once(struct vcache *avc)
     }
 
     dcList = osi_Alloc(dcListMax * sizeof(struct dcache *));
-    dcListCount = 0;
 
     for (index = afs_dvhashTbl[hash]; index != NULLIDX;) {
 	if (afs_indexUnique[index] == avc->f.fid.Fid.Unique) {
