@@ -12,8 +12,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#include <roken.h>
-
 #include <afs/stds.h>
 #include <afs/opr.h>
 #include <afs/pthread_glock.h>
@@ -24,7 +22,10 @@
 #endif
 
 #if defined(UKERNEL)
-#include "afsincludes.h"
+# include "afsincludes.h"
+# include <afs_usrops.h>
+#else
+# include <roken.h>
 #endif
 
 #ifdef	AFS_AIX_ENV
@@ -119,7 +120,7 @@ static void ktc_LocalCell(void);
 #endif /* AFS_KERBEROS_ENV */
 
 #if defined(UKERNEL)
-#define PIOCTL(A,B,C,D) (errno = (call_syscall(AFSCALL_PIOCTL,A,B,C,D)), errno?-1:0)
+#define PIOCTL(A,B,C,D) (errno = (call_syscall(AFSCALL_PIOCTL,A,B,(long)C,D,0)), errno?-1:0)
 #else
 #define PIOCTL pioctl
 #endif
