@@ -9,42 +9,30 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
-
-
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#include <io.h>
-#include <fcntl.h>
-#else
-#include <netinet/in.h>
-#include <sys/time.h>
-#include <sys/resource.h>
-#include <sys/file.h>
-#endif
-#include <time.h>
-#include <sys/types.h>
 #include <afs/stds.h>
-#include <stdio.h>
-#ifdef HAVE_STDINT_H
-# include <stdint.h>
+
+#include <roken.h>
+
+#include <afs/opr.h>
+
+#ifdef AFS_PTHREAD_ENV
+# include <opr/lock.h>
 #endif
-#include <lock.h>
+
 #include <ubik.h>
 #include <lwp.h>
-#include <rx/xdr.h>
 #include <rx/rx.h>
 #include <rx/rxkad.h>
-#include <string.h>
-#include <des.h>
 #include <afs/cellconfig.h>
-#include <errno.h>
+#include <afs/audit.h>
+#include <afs/afsutil.h>
+
 #include "budb.h"
 #include "budb_errs.h"
 #include "database.h"
 #include "budb_internal.h"
 #include "error_macros.h"
 #include "globals.h"
-#include "afs/audit.h"
 
 afs_int32 DumpDB(struct rx_call *, int, afs_int32, charListT *, afs_int32 *);
 afs_int32 RestoreDbHeader(struct rx_call *, struct DbHeader *);
@@ -73,6 +61,7 @@ setupDbDump(void *param)
     int writeFid = (intptr_t)param;
     afs_int32 code = 0;
 
+    opr_threadname_set("Database Dumper");
     code = InitRPC(&dumpSyncPtr->ut, LOCKREAD, 1);
     if (code)
 	goto error_exit;
@@ -162,16 +151,19 @@ DumpDB(struct rx_call *call,
 	/* Initialize the condition variables and the mutexes we use
 	 * to signal and synchronize the reader and writer threads.
 	 */
-	CV_INIT(&dumpSyncPtr->ds_readerStatus_cond, "reader cond", CV_DEFAULT, 0);
-	CV_INIT(&dumpSyncPtr->ds_writerStatus_cond, "writer cond", CV_DEFAULT, 0);
-	MUTEX_INIT(&dumpSyncPtr->ds_readerStatus_mutex, "reader", MUTEX_DEFAULT, 0);
-	MUTEX_INIT(&dumpSyncPtr->ds_writerStatus_mutex, "writer", MUTEX_DEFAULT, 0);
+	opr_cv_init(&dumpSyncPtr->ds_readerStatus_cond);
+	opr_cv_init(&dumpSyncPtr->ds_writerStatus_cond);
+	opr_mutex_init(&dumpSyncPtr->ds_readerStatus_mutex);
+	opr_mutex_init(&dumpSyncPtr->ds_writerStatus_mutex);
 
 	/* Initialize the thread attributes and launch the thread */
 
-	osi_Assert(pthread_attr_init(&dumperPid_tattr) == 0);
-	osi_Assert(pthread_attr_setdetachstate(&dumperPid_tattr, PTHREAD_CREATE_DETACHED) == 0);
-	osi_Assert(pthread_create(&dumperPid, &dumperPid_tattr, (void *)setupDbDump, NULL) == 0);
+	opr_Verify(pthread_attr_init(&dumperPid_tattr) == 0);
+	opr_Verify(pthread_attr_setdetachstate(&dumperPid_tattr,
+					       PTHREAD_CREATE_DETACHED) == 0);
+	opr_Verify(pthread_create(&dumperPid,
+				  &dumperPid_tattr,
+				  (void *)setupDbDump, NULL) == 0);
 
 #else
 	code =
@@ -188,9 +180,12 @@ DumpDB(struct rx_call *call,
 #ifdef AFS_PTHREAD_ENV
 	/* Initialize the thread attributes and launch the thread */
 
-	osi_Assert(pthread_attr_init(&watcherPid_tattr) == 0);
-	osi_Assert(pthread_attr_setdetachstate(&watcherPid_tattr, PTHREAD_CREATE_DETACHED) == 0);
-	osi_Assert(pthread_create(&watcherPid, &watcherPid_tattr, (void *)dumpWatcher, NULL) == 0);
+	opr_Verify(pthread_attr_init(&watcherPid_tattr) == 0);
+	opr_Verify(pthread_attr_setdetachstate(&watcherPid_tattr,
+					       PTHREAD_CREATE_DETACHED) == 0);
+	opr_Verify(pthread_create(&watcherPid,
+				  &watcherPid_tattr,
+				  (void *)dumpWatcher, NULL) == 0);
 #else
 	/* now create the watcher thread */
 	code =
@@ -214,7 +209,7 @@ DumpDB(struct rx_call *call,
 	    LogDebug(6, "wakup writer\n");
 	    dumpSyncPtr->ds_writerStatus = 0;
 #ifdef AFS_PTHREAD_ENV
-	    CV_BROADCAST(&dumpSyncPtr->ds_writerStatus_cond);
+	    opr_cv_broadcast(&dumpSyncPtr->ds_writerStatus_cond);
 #else
 	    code = LWP_SignalProcess(&dumpSyncPtr->ds_writerStatus);
 	    if (code)
@@ -225,16 +220,16 @@ DumpDB(struct rx_call *call,
 	dumpSyncPtr->ds_readerStatus = DS_WAITING;
 	ReleaseWriteLock(&dumpSyncPtr->ds_lock);
 #ifdef AFS_PTHREAD_ENV
-        MUTEX_ENTER(&dumpSyncPtr->ds_readerStatus_mutex);
-        CV_WAIT(&dumpSyncPtr->ds_readerStatus_cond, &dumpSyncPtr->ds_readerStatus_mutex);
-        MUTEX_EXIT(&dumpSyncPtr->ds_readerStatus_mutex);
+        opr_mutex_enter(&dumpSyncPtr->ds_readerStatus_mutex);
+        opr_cv_wait(&dumpSyncPtr->ds_readerStatus_cond, &dumpSyncPtr->ds_readerStatus_mutex);
+        opr_mutex_exit(&dumpSyncPtr->ds_readerStatus_mutex);
 #else
 	LWP_WaitProcess(&dumpSyncPtr->ds_readerStatus);
 #endif
 	ObtainWriteLock(&dumpSyncPtr->ds_lock);
     }
 
-    charListPtr->charListT_val = (char *)malloc(maxLength);
+    charListPtr->charListT_val = malloc(maxLength);
     readSize =
 	read(dumpSyncPtr->pipeFid[0], charListPtr->charListT_val, maxLength);
 
@@ -256,7 +251,7 @@ DumpDB(struct rx_call *call,
     if (dumpSyncPtr->ds_writerStatus == DS_WAITING) {
 	dumpSyncPtr->ds_writerStatus = 0;
 #ifdef AFS_PTHREAD_ENV
-	CV_BROADCAST(&dumpSyncPtr->ds_writerStatus_cond);
+	opr_cv_broadcast(&dumpSyncPtr->ds_writerStatus_cond);
 #else
 	code = LWP_SignalProcess(&dumpSyncPtr->ds_writerStatus);
 	if (code)
@@ -332,6 +327,7 @@ dumpWatcher(void *unused)
 {
     afs_int32 code;
 
+    opr_threadname_set("Database Dump Watchdog");
     while (1) {			/*w */
 
 	/* printf("dumpWatcher\n"); */
@@ -352,7 +348,7 @@ dumpWatcher(void *unused)
 	    close(dumpSyncPtr->pipeFid[0]);
 	    close(dumpSyncPtr->pipeFid[1]);
 #ifdef AFS_PTHREAD_ENV
-	    osi_Assert(pthread_cancel(dumpSyncPtr->dumperPid) == 0);
+	    opr_Verify(pthread_cancel(dumpSyncPtr->dumperPid) == 0);
 #else
 	    code = LWP_DestroyProcess(dumpSyncPtr->dumperPid);
 	    if (code)
