@@ -29,7 +29,6 @@
 #define FTRUNC O_TRUNC
 
 #define AFS_SYSCALL		208
-#define AFS_MOUNT_AFS		"afs"
 
 #define RXK_LISTENER_ENV	1
 #define AFS_GCPAGS	        0	/* if nonzero, garbage collect PAGs */
@@ -45,14 +44,6 @@
 
 #if	!defined(ASSEMBLER) && !defined(__LANGUAGE_ASSEMBLY__)
 enum vcexcl { NONEXCL, EXCL };
-
-#ifndef MIN
-#define MIN(A,B) ((A) < (B) ? (A) : (B))
-#endif
-#ifndef MAX
-#define MAX(A,B) ((A) > (B) ? (A) : (B))
-#endif
-
 #endif /* ! ASSEMBLER & ! __LANGUAGE_ASSEMBLY__ */
 #endif /* _KERNEL */
 
