@@ -51,6 +51,32 @@ struct DirHeader {
     unsigned short hashTable[NHASHENT];
 };
 
+/*
+ * This struct is just a copy of DirEntry, but with name defined as a flexible
+ * array if possible.
+ *
+ * Using this helps us convince safety-minded string functions (e.g.
+ * _FORTIFY_SOURCE) that an OpenAFS directory entry name really does fit
+ * in the allotted space, and thus avoid undefined behavior.
+ */
+struct DirEntryFlex {
+    char flag;
+    char length;                /* currently unused */
+    unsigned short next;
+    struct MKFid fid;
+#ifdef HAVE_FLEXIBLE_ARRAY
+    char name[];
+#else
+    char name[16];
+#endif
+};
+
+/*
+ * This struct was the original format for directory entries in very early
+ * versions of AFS.  But now it just represents the minimum possible on-disk
+ * representation of a directory entry.  The 16-character limit was relieved by
+ * the introduction of extension struct DirXEntry in AFS-2.
+*/
 struct DirEntry {
     /* A directory entry */
     char flag;
@@ -104,6 +130,8 @@ extern int afs_dir_EnumerateDir(dir_file_t dir,
 extern int afs_dir_IsEmpty(dir_file_t dir);
 extern int afs_dir_GetBlob(dir_file_t dir, afs_int32 blobno,
 			   struct DirBuffer *);
+extern int afs_dir_GetBlobWithErrno(dir_file_t dir, afs_int32 blobno,
+			   struct DirBuffer *, int *physerr);
 extern int afs_dir_GetVerifiedBlob(dir_file_t dir, afs_int32 blobno,
 				   struct DirBuffer *);
 extern int afs_dir_DirHash(char *string);
@@ -119,6 +147,7 @@ extern int afs_dir_ChangeFid(dir_file_t dir, char *entry,
 
 extern void DInit(int abuffers);
 extern int DRead(dir_file_t fid, int page, struct DirBuffer *);
+extern int DReadWithErrno(dir_file_t fid, int page, struct DirBuffer *, int *physerr);
 extern int DFlush(void);
 extern int DFlushVolume(afs_int32);
 extern int DNew(dir_file_t fid, int page, struct DirBuffer *);
