@@ -18,11 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-
-/* On DUX "IN" is a variable in curses.h, so this can be a bit of a problem */
-#ifdef IN
-#undef IN
-#endif
+#include <roken.h>
 
 #include "gtxwindows.h"		/*Interface for this module */
 #include "gtxcurseswin.h"	/*Interface for the curses module */
