@@ -11,23 +11,17 @@
  * Glue code for the kopenafs API.  Mostly just wrappers around the functions
  * included in the libsys code.
  */
-
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#include <errno.h>
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <signal.h>
-#include <stdlib.h>
+#include <roken.h>
+
 #ifdef AFS_AIX51_ENV
 # include <sys/cred.h>
 # ifdef HAVE_SYS_PAG_H
 #  include <sys/pag.h>
 # endif
 #endif
-#include <sys/param.h>
-#include <unistd.h>
 
 #include <afs/afssyscalls.h>
 #include <kopenafs.h>
@@ -36,7 +30,7 @@ static volatile sig_atomic_t syscall_okay = 1;
 
 /* Signal handler to catch failed system calls and change the okay flag. */
 #ifdef SIGSYS
-static RETSIGTYPE
+static void
 sigsys_handler(int s)
 {
     syscall_okay = 0;
@@ -49,7 +43,7 @@ k_hasafs(void)
 {
     struct ViceIoctl iob;
     int okay, saved_errno;
-    RETSIGTYPE (*saved_func)(int);
+    void (*saved_func)(int);
 
     saved_errno = errno;
 
@@ -77,7 +71,13 @@ k_hasafs(void)
 int
 k_setpag(void)
 {
-    return lsetpag();
+    int code;
+
+    do {
+	code = lsetpag();
+    } while (code && errno == EINTR);
+
+    return code;
 }
 
 int
