@@ -16,17 +16,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#include <errno.h>
+#include <roken.h>
 
-#include <sys/types.h>
-#ifdef AFS_NT40_ENV
-#include <winsock2.h>
-#else
-#include <netinet/in.h>
-#endif
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <afs/ptclient.h>
+
 #include "acl.h"
 
 /*!
