@@ -14,9 +14,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
 #include "kas.h"
-#include <time.h>
 
 /*
  * Utility functions
@@ -52,6 +52,10 @@ DoKasPrincipalCreate(struct cmd_syndesc *as, void *arock)
     kas_identity_t user;
     const char *password;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     strcpy(user.principal, as->parms[PRINCIPAL].items->data);
 
     if (as->parms[INSTANCE].items) {
@@ -76,6 +80,10 @@ DoKasPrincipalDelete(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     kas_identity_t user;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     strcpy(user.principal, as->parms[PRINCIPAL].items->data);
 
     if (as->parms[INSTANCE].items) {
@@ -163,6 +171,10 @@ DoKasPrincipalGet(struct cmd_syndesc *as, void *arock)
     kas_identity_t user;
     kas_principalEntry_t principal;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     strcpy(user.principal, as->parms[PRINCIPAL].items->data);
 
     if (as->parms[INSTANCE].items) {
@@ -187,6 +199,10 @@ DoKasPrincipalList(struct cmd_syndesc *as, void *arock)
     void *iter;
     kas_identity_t prin;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     if (!kas_PrincipalGetBegin(cellHandle, 0, &iter, &st)) {
 	ERR_ST_EXT("kas_PrincipalGetBegin", st);
     }
@@ -225,6 +241,10 @@ DoKasPrincipalKeySet(struct cmd_syndesc *as, void *arock)
     const char *cell;
     const char *password;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     strcpy(user.principal, as->parms[PRINCIPAL].items->data);
 
     if (as->parms[INSTANCE].items) {
@@ -260,6 +280,10 @@ DoKasPrincipalLockStatusGet(struct cmd_syndesc *as, void *arock)
     kas_identity_t user;
     unsigned int lock_end_time = 0;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     strcpy(user.principal, as->parms[PRINCIPAL].items->data);
 
     if (as->parms[INSTANCE].items) {
@@ -285,6 +309,10 @@ DoKasPrincipalUnlock(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     kas_identity_t user;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     strcpy(user.principal, as->parms[PRINCIPAL].items->data);
 
     if (as->parms[INSTANCE].items) {
@@ -342,6 +370,10 @@ DoKasPrincipalFieldsSet(struct cmd_syndesc *as, void *arock)
     unsigned int *failed_password_lock_time_ptr = NULL;
     int have_failed_password_lock_time = 0;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     strcpy(user.principal, as->parms[PRINCIPAL].items->data);
 
     if (as->parms[INSTANCE].items) {
@@ -551,6 +583,10 @@ DoKasServerStatsGet(struct cmd_syndesc *as, void *arock)
     void *kas_server = NULL;
     kas_serverStats_t stats;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     if (as->parms[SERVER].items) {
 	server_list[0] = as->parms[SERVER].items->data;
     }
@@ -636,6 +672,10 @@ DoKasServerDebugGet(struct cmd_syndesc *as, void *arock)
     void *kas_server = NULL;
     kas_serverDebugInfo_t debug;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     if (as->parms[SERVER].items) {
 	server_list[0] = as->parms[SERVER].items->data;
     }
@@ -662,6 +702,10 @@ DoKasServerRandomKeyGet(struct cmd_syndesc *as, void *arock)
     kas_encryptionKey_t key;
     int i;
 
+    if (existing_tokens) {
+	ERR_EXT("can't use -usetokens with kas functions");
+    }
+
     if (!kas_ServerRandomKeyGet(cellHandle, 0, &key, &st)) {
 	ERR_ST_EXT("kas_ServerRandomKeyGet", st);
     }
@@ -680,7 +724,7 @@ SetupKasAdminCmd(void)
 {
     struct cmd_syndesc *ts;
 
-    ts = cmd_CreateSyntax("KasPrincipalCreate", DoKasPrincipalCreate, NULL,
+    ts = cmd_CreateSyntax("KasPrincipalCreate", DoKasPrincipalCreate, NULL, 0,
 			  "create a new principal");
     cmd_AddParm(ts, "-principal", CMD_SINGLE, CMD_REQUIRED,
 		"principal to create");
@@ -690,7 +734,7 @@ SetupKasAdminCmd(void)
 		"initial principal password");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasPrincipalDelete", DoKasPrincipalDelete, NULL,
+    ts = cmd_CreateSyntax("KasPrincipalDelete", DoKasPrincipalDelete, NULL, 0,
 			  "delete a principal");
     cmd_AddParm(ts, "-principal", CMD_SINGLE, CMD_REQUIRED,
 		"principal to delete");
@@ -698,7 +742,7 @@ SetupKasAdminCmd(void)
 		"principal instance");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasPrincipalGet", DoKasPrincipalGet, NULL,
+    ts = cmd_CreateSyntax("KasPrincipalGet", DoKasPrincipalGet, NULL, 0,
 			  "get information about a principal");
     cmd_AddParm(ts, "-principal", CMD_SINGLE, CMD_REQUIRED,
 		"principal to get");
@@ -706,11 +750,11 @@ SetupKasAdminCmd(void)
 		"principal instance");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasPrincipalList", DoKasPrincipalList, NULL,
+    ts = cmd_CreateSyntax("KasPrincipalList", DoKasPrincipalList, NULL, 0,
 			  "list all principals");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasPrincipalKeySet", DoKasPrincipalKeySet, NULL,
+    ts = cmd_CreateSyntax("KasPrincipalKeySet", DoKasPrincipalKeySet, NULL, 0,
 			  "set the password for a principal");
     cmd_AddParm(ts, "-principal", CMD_SINGLE, CMD_REQUIRED,
 		"principal to modify");
@@ -723,7 +767,7 @@ SetupKasAdminCmd(void)
     SetupCommonCmdArgs(ts);
 
     ts = cmd_CreateSyntax("KasPrincipalLockStatusGet",
-			  DoKasPrincipalLockStatusGet, NULL,
+			  DoKasPrincipalLockStatusGet, NULL, 0,
 			  "get the lock status of a principal");
     cmd_AddParm(ts, "-principal", CMD_SINGLE, CMD_REQUIRED,
 		"principal to query");
@@ -731,7 +775,7 @@ SetupKasAdminCmd(void)
 		"principal instance");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasPrincipalUnlock", DoKasPrincipalUnlock, NULL,
+    ts = cmd_CreateSyntax("KasPrincipalUnlock", DoKasPrincipalUnlock, NULL, 0,
 			  "unlock a principal");
     cmd_AddParm(ts, "-principal", CMD_SINGLE, CMD_REQUIRED,
 		"principal to unlock");
@@ -739,7 +783,7 @@ SetupKasAdminCmd(void)
 		"principal instance");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasPrincipalFieldsSet", DoKasPrincipalFieldsSet, NULL,
+    ts = cmd_CreateSyntax("KasPrincipalFieldsSet", DoKasPrincipalFieldsSet, NULL, 0,
 			  "modify a principal");
     cmd_AddParm(ts, "-principal", CMD_SINGLE, CMD_REQUIRED,
 		"principal to modify");
@@ -779,17 +823,17 @@ SetupKasAdminCmd(void)
 		"maximum failed password attempts is exceeded");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasServerStatsGet", DoKasServerStatsGet, NULL,
+    ts = cmd_CreateSyntax("KasServerStatsGet", DoKasServerStatsGet, NULL, 0,
 			  "get stats on a kaserver");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED, "server to query");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasServerDebugGet", DoKasServerDebugGet, NULL,
+    ts = cmd_CreateSyntax("KasServerDebugGet", DoKasServerDebugGet, NULL, 0,
 			  "get debug info from a kaserver");
     cmd_AddParm(ts, "-server", CMD_SINGLE, CMD_REQUIRED, "server to query");
     SetupCommonCmdArgs(ts);
 
-    ts = cmd_CreateSyntax("KasServerRandomKeyGet", DoKasServerRandomKeyGet, NULL,
+    ts = cmd_CreateSyntax("KasServerRandomKeyGet", DoKasServerRandomKeyGet, NULL, 0,
 			  "create a random key");
     SetupCommonCmdArgs(ts);
 
