@@ -332,10 +332,11 @@
 
     //link configuration
     NSData *prefData = (NSData*)CFPreferencesCopyValue((CFStringRef)PREFERENCE_LINK_CONFIGURATION,  (CFStringRef)kAfsCommanderID,  kCFPreferencesCurrentUser, kCFPreferencesAnyHost);
-    linkConfiguration = (NSMutableDictionary*)[NSPropertyListSerialization propertyListFromData:prefData
-									   mutabilityOption:NSPropertyListMutableContainers
-									   format:nil
-									   errorDescription:nil];
+    NSDictionary *linkDict = (NSMutableDictionary*)[NSPropertyListSerialization propertyListFromData:prefData
+										mutabilityOption:NSPropertyListMutableContainers
+										format:nil
+										errorDescription:nil];
+    linkConfiguration = [linkDict mutableCopy];
 }
 
 // -------------------------------------------------------------------------------
@@ -568,7 +569,7 @@
     
     case REMOVE_CELL_CONTROL_TAG:
     {
-	int index = 0;
+	NSUInteger index;
 	NSIndexSet *selectedIndex = [(NSTableView*)cellList selectedRowIndexes];
 	if( [selectedIndex count] > 0) {
 	    index = [selectedIndex firstIndex];
@@ -696,7 +697,7 @@
 // -------------------------------------------------------------------------------
 - (IBAction) unlog:(id) sender
 {
-    int index = -1;
+    NSUInteger index;
     NSIndexSet *selectedIndex = [tokensTable selectedRowIndexes];
     if( [selectedIndex count] > 0) {
 	index = [selectedIndex firstIndex];
@@ -749,14 +750,13 @@
 //  afsStartupSwitchEvent:
 // -------------------------------------------------------------------------------
 - (IBAction) afsStartupSwitchEvent:(id) sender {
-    NSString *rootHelperApp = [[self bundle] pathForResource:@"afshlp" ofType:@""];
     //get the new state
     startAFSAtLogin = [checkButtonAfsAtBootTime state];
-    [PListManager launchctlStringCommandAuth:startAFSAtLogin?@"load":@"unload"
-		  option:[NSArray arrayWithObjects:@"-w", nil]
-		  plistName:@AFS_DAEMON_PATH
-		  helper:rootHelperApp
-		  withAuthRef:[[authView authorization] authorizationRef]];
+    if (startAFSAtLogin) {
+	[TaskUtil executePrivTask:"startup_enable"];
+    } else {
+	[TaskUtil executePrivTask:"startup_disable"];
+    }
 }
 
 
@@ -877,16 +877,13 @@
 {
     BOOL afsIsUp = [afsProperty checkAfsStatus];
     BOOL afsEnabledAtStartup = NO;
-    NSString *rootHelperApp = [[self bundle] pathForResource:@"afshlp" ofType:@""];
 
     if ([self isUnlocked]) {
-	afsEnabledAtStartup = (
-	    [TaskUtil executeTaskWithAuth:@"/bin/launchctl"
-		      arguments:[NSArray arrayWithObjects:@"list",
-					 @"org.openafs.filesystems.afs", nil]
-		      helper:rootHelperApp
-		      withAuthRef:[[authView authorization] authorizationRef]
-	     ] == noErr)?YES:NO;
+	if ([TaskUtil executePrivTask:"startup_check"] == 0) {
+	    afsEnabledAtStartup = YES;
+	} else {
+	    afsEnabledAtStartup = NO;
+	}
 	[checkButtonAfsAtBootTime setState:afsEnabledAtStartup];
     }
 
@@ -940,14 +937,14 @@
 // -------------------------------------------------------------------------------
 - (IBAction) removeLink:(id) sender {
     if(!linkConfiguration) return;
-    int index = 0;
+    NSUInteger index;
     NSArray *keys = [linkConfiguration allKeys];
     NSIndexSet *linkToRemove = [tableViewLink selectedRowIndexes];
     if( [linkToRemove count] > 0) {
 	index = [linkToRemove firstIndex];
 	do {
 	    [linkConfiguration removeObjectForKey:[keys objectAtIndex:index]];
-	} while ((index = [linkToRemove indexGreaterThanIndex:index]) != -1);
+	} while ((index = [linkToRemove indexGreaterThanIndex:index]) != NSNotFound);
     }
 
     //write the new configuration
@@ -1042,6 +1039,17 @@
     [checkButtonAfsAtBootTime setEnabled:[self isUnlocked]];
     [installKRB5AuthAtLoginButton setEnabled:[self isUnlocked]];
 }
+
+// These are called when the user clicks on the lock icon in the prefpane to
+// authenticate to make system changes. Store a reference to the authorization
+// context that we can use for privileged operations.
+- (void)authorizationViewCreatedAuthorization:(SFAuthorizationView *)view {
+    [[AuthUtil shared] setAuthorization:[[authView authorization] authorizationRef]];
+}
+
+- (void)authorizationViewReleasedAuthorization:(SFAuthorizationView *)view {
+    [[AuthUtil shared] setAuthorization:nil];
+}
 @end
 
 @implementation AFSCommanderPref (NSTableDataSource)
