@@ -129,6 +129,7 @@
 #include <rx/rxstat.h>
 #include <lock.h>
 #include <ubik.h>
+#include <afs/authcon.h>
 #include <afs/cmd.h>
 #include <afs/cellconfig.h>
 #include <afs/auth.h>
@@ -249,6 +250,7 @@ main(int argc, char **argv)
     afs_int32 numClasses;
     int lwps = 3;
     char clones[MAXHOSTSPERCELL];
+    char hoststr[16];
     afs_uint32 host = htonl(INADDR_ANY);
     struct cmd_syndesc *opts;
     struct cmd_item *list;
@@ -260,6 +262,7 @@ main(int argc, char **argv)
 
     char *auditFileName = NULL;
     char *interface = NULL;
+    struct afsconf_bsso_info bsso;
 
 #ifdef	AFS_AIX32_ENV
     /*
@@ -279,6 +282,8 @@ main(int argc, char **argv)
     osi_audit_init();
     osi_audit(PTS_StartEvent, 0, AUD_END);
 
+    memset(&bsso, 0, sizeof(bsso));
+
     /* Initialize dirpaths */
     if (!(initAFSDirPath() & AFSDIR_SERVER_PATHS_OK)) {
 #ifdef AFS_NT40_ENV
@@ -541,14 +546,17 @@ main(int argc, char **argv)
 	}
 	if (ccode == 1) {
 	    host = SHostAddrs[0];
-	    /* the following call is idempotent so if/when it gets called
-	     * again by the ubik init stuff, it doesn't really matter
-	     * -- klm
-	     */
-	    rx_InitHost(host, htons(AFSCONF_PROTPORT));
 	}
     }
 
+    ViceLog(0, ("ptserver binding rx to %s:%d\n",
+            afs_inet_ntoa_r(host, hoststr), AFSCONF_PROTPORT));
+    code = rx_InitHost(host, htons(AFSCONF_PROTPORT));
+    if (code < 0) {
+	ViceLog(0, ("ptserver: Rx init failed: %d\n", code));
+	PT_EXIT(1);
+    }
+
     /* Disable jumbograms */
     rx_SetNoJumbo();
 
@@ -571,7 +579,10 @@ main(int argc, char **argv)
     pt_hook_write();
 #endif
 
-    afsconf_BuildServerSecurityObjects(prdir, &securityClasses, &numClasses);
+    bsso.dir = prdir;
+    bsso.logger = FSLog;
+    afsconf_BuildServerSecurityObjects_int(&bsso, &securityClasses,
+					   &numClasses);
 
     tservice =
 	rx_NewServiceHost(host, 0, PRSRV, "Protection Server", securityClasses,
@@ -583,8 +594,12 @@ main(int argc, char **argv)
     rx_SetMinProcs(tservice, 2);
     rx_SetMaxProcs(tservice, lwps);
     if (rxkadDisableDotCheck) {
-        rx_SetSecurityConfiguration(tservice, RXS_CONFIG_FLAGS,
-                                    (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	code = rx_SetSecurityConfiguration(tservice, RXS_CONFIG_FLAGS,
+					   (void *)RXS_CONFIG_FLAGS_DISABLE_DOTCHECK);
+	if (code) {
+	    afs_com_err(whoami, code, "Failed to allow dotted principals");
+	    PT_EXIT(3);
+	}
     }
 
     tservice =
@@ -607,13 +622,6 @@ main(int argc, char **argv)
 		   "1.0",
 #endif
 		   "Starting AFS", FSLog);
-    if (afsconf_CountKeys(prdir) == 0) {
-	ViceLog(0, ("WARNING: No encryption keys found! "
-		    "All authenticated accesses will fail. "
-		    "Run akeyconvert or asetkey to import encryption keys.\n"));
-    } else if (afsconf_GetLatestKey(prdir, NULL, NULL) == 0) {
-	LogDesWarning();
-    }
 
     rx_StartServer(1);
     osi_audit(PTS_FinishEvent, -1, AUD_END);
