@@ -24,9 +24,10 @@ extern void rx_rto_setPeerTimeoutSecs(struct rx_peer *, int secs);
 
 extern int rx_Init(u_int port);
 extern int rx_InitHost(u_int host, u_int port);
-#ifdef AFS_NT40_ENV
+
 extern void rx_DebugOnOff(int on);
 extern void rx_StatsOnOff(int on);
+#ifdef AFS_NT40_ENV
 extern void rx_StartClientThread(void);
 #endif
 extern void rx_StartServer(int donateMe);
@@ -84,6 +85,9 @@ extern void rxi_CallError(struct rx_call *call, afs_int32 error);
 extern void rx_SetConnSecondsUntilNatPing(struct rx_connection *conn,
 					  afs_int32 seconds);
 extern int rxs_Release(struct rx_securityClass *aobj);
+extern struct rx_securityClass *rxs_Ref(struct rx_securityClass *aobj);
+extern int rxs_DecRef(struct rx_securityClass *aobj);
+extern void rxs_SetRefs(struct rx_securityClass *aobj, int refs);
 #ifndef KERNEL
 extern void rx_PrintTheseStats(FILE * file, struct rx_statistics *s, int size,
 			       afs_int32 freePackets, char version);
@@ -332,6 +336,8 @@ extern void rxi_ListenerProc(osi_socket usockp, int *tnop,
 extern void rxk_init(void);
 # endif
 
+extern osi_socket *rxk_NewSocketHost(afs_uint32 ahost, short aport);
+
 /* UKERNEL/rx_knet.c */
 # ifdef UKERNEL
 extern void afs_rxevent_daemon(void);
