@@ -53,7 +53,7 @@ quitSignal(int ignore)
 	rx_PrintStats(debugFile);
 }
 
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX_ENV)
 int
 test_syscall(a3, a4, a5)
      afs_uint32 a3, a4;
@@ -80,7 +80,7 @@ main(argc, argv)
     int setFD = 0;
     int jumbo = 0;
 
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX_ENV)
     setlinebuf(stdout);
     rxi_syscallp = test_syscall;
 #endif
@@ -94,8 +94,15 @@ main(argc, argv)
 	else if (strcmp(*argv, "-rxlog") == 0)
 	    rxlog = 1;
 #if defined(RXDEBUG) && !defined(AFS_NT40_ENV)
-	else if (strcmp(*argv, "-trace") == 0)
-	    strcpy(rxi_tracename, *(++argv)), argc--;
+	else if (strcmp(*argv, "-trace") == 0) {
+	    extern char rxi_tracename[80];
+	    argv++;
+	    argc--;
+	    if (strlcpy(rxi_tracename, *argv,
+			sizeof(rxi_tracename)) >= sizeof(rxi_tracename)) {
+		Quit("-trace argument too long");
+	    }
+	}
 #endif
 	else if (strcmp(*argv, "-logstdout") == 0)
 	    logstdout = 1;
