@@ -28,21 +28,17 @@
  */
 
 #include <afsconfig.h>
-#ifdef KERNEL
-#include "afs/param.h"
-#else
 #include <afs/param.h>
-#endif
 
 
 #ifndef	NeXT
 
 #if defined(KERNEL) && !defined(UKERNEL)
-# if !defined(AFS_LINUX26_ENV)
+# if !defined(AFS_LINUX_ENV)
 #  include <sys/param.h>
 # endif
 #else
-# include <stdio.h>
+# include <roken.h>
 #endif
 #include "xdr.h"
 
