@@ -406,7 +406,7 @@ afs_lhash_remove(afs_lhash * lh, unsigned key, const void *data)
 	 pprev = &cur->next, cur = cur->next) {
 	lh->remove_tests++;
 	if (lh->equal(data, cur->data)) {
-	    void *data = cur->data;
+	    void *ptr = cur->data;
 
 	    if (pprev) {
 		*pprev = cur->next;
@@ -418,7 +418,7 @@ afs_lhash_remove(afs_lhash * lh, unsigned key, const void *data)
 
 	    lh->ndata--;
 
-	    return data;
+	    return ptr;
 	}
     }
 
@@ -455,9 +455,6 @@ afs_lhash_enter(afs_lhash * lh, unsigned key, void *data)
      */
     if (lh->ndata > LOAD_FACTOR * lh->ltable) {
 	afs_lhash_expand(lh);
-#if 0
-	printf("lh->p = %d; lh->maxp = %d\n", lh->p, lh->maxp);
-#endif
     }
 #ifdef CHECK_INVARIANTS
     assert(lh->ndata <= LOAD_FACTOR * lh->ltable);
