@@ -10,11 +10,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
 #ifdef AFS_HPUX_ENV
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/time.h>
 #include <utime.h>
 
 /* insque/remque moved to timer.c where they are used. */
@@ -31,24 +29,6 @@ utimes(char *file, struct timeval tvp[2])
 }
 #endif
 
-int
-random(void)
-{
-    return rand();
-}
-
-void
-srandom(int seed)
-{
-    srand(seed);
-}
-
-int
-getdtablesize(void)
-{
-    return (20);
-}
-
 void
 setlinebuf(FILE * file)
 {
