@@ -9,32 +9,19 @@
 
 #include <afsconfig.h>
 #include <afs/param.h>
+#include <afs/stds.h>
 
+#include <roken.h>
 
 #include <rx/xdr.h>
-#include <sys/ioctl.h>
-#include <sys/socket.h>
-#include <netdb.h>
-#include <errno.h>
-#include <stdio.h>
-#include <netinet/in.h>
-#include <sys/stat.h>
-#include <afs/stds.h>
 #include <afs/vice.h>
 #include <afs/venus.h>
-#ifdef	AFS_AIX32_ENV
-#include <signal.h>
-#endif
 #undef VIRTUE
 #undef VICE
 #include "afs/prs_fs.h"
 #include <afs/afsint.h>
 #include <afs/cellconfig.h>
 #include <afs/cmd.h>
-#include <strings.h>
-
-
-
 
 #include "AFS_component_version_number.c"
 
