@@ -16,22 +16,16 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
-#include <stdio.h>
-#include <errno.h>
-#include <string.h>
-#ifdef AFS_NT40_ENV
-#include <fcntl.h>
-#else
+#ifdef HAVE_SYS_FILE_H
 #include <sys/file.h>
-#include <sys/time.h>
-#include <unistd.h>
 #endif
+
+#include <rx/rx_queue.h>
 #include <afs/nfs.h>
-#include <afs/afs_assert.h>
 #include <lwp.h>
 #include <lock.h>
-#include <time.h>
 #include <afs/afsint.h>
 #include <afs/ihandle.h>
 #include <afs/vnode.h>
@@ -45,41 +39,63 @@
 
 afs_int32 lpErrno, lpCount;
 
-/* returns 0 on success, errno on failure */
+/*
+ * Read the specified page from a directory object
+ *
+ * \parm[in] file      handle to the directory object
+ * \parm[in] block     requested page from the directory object
+ * \parm[out] data     buffer for the returned page
+ * \parm[out] physerr  (optional) pointer to errno if physical error
+ *
+ * \retval 0   success
+ * \retval EIO physical or logical error;
+ *             if physerr is supplied by caller, it will be set to:
+ *                 0       for logical errors
+ *                 errno   for physical errors
+ */
 int
-ReallyRead(DirHandle * file, int block, char *data)
+ReallyRead(DirHandle *file, int block, char *data, int *physerr)
 {
-    int code;
+    int saverr = 0;
+    int code = 0;
     ssize_t rdlen;
     FdHandle_t *fdP;
     afs_ino_str_t stmp;
 
     fdP = IH_OPEN(file->dirh_handle);
     if (fdP == NULL) {
-	code = errno;
+	saverr = errno;
+	code = EIO;
 	ViceLog(0,
-		("ReallyRead(): open failed device %X inode %s (volume=%u) errno %d\n",
+		("ReallyRead(): open failed device %X inode %s (volume=%" AFS_VOLID_FMT ") errno %d\n",
 		 file->dirh_handle->ih_dev, PrintInode(stmp,
 						       file->dirh_handle->
-						       ih_ino), file->dirh_handle->ih_vid,code));
-	return code;
+						       ih_ino), 
+		 afs_printable_VolumeId_lu(file->dirh_handle->ih_vid), saverr));
+	goto done;
     }
     rdlen = FDH_PREAD(fdP, data, PAGESIZE, ((afs_foff_t)block) * PAGESIZE);
     if (rdlen != PAGESIZE) {
 	if (rdlen < 0)
-	    code = errno;
+	    saverr = errno;
 	else
-	    code = EIO;
+	    saverr = 0;	    /* logical error: short read */
+	code = EIO;
 	ViceLog(0,
-		("ReallyRead(): read failed device %X inode %s (volume=%u) errno %d\n",
+		("ReallyRead(): read failed device %X inode %s (volume=%" AFS_VOLID_FMT ") errno %d\n",
 		 file->dirh_handle->ih_dev, PrintInode(stmp,
 						       file->dirh_handle->
-						       ih_ino), file->dirh_handle->ih_vid,code));
+						       ih_ino),
+		 afs_printable_VolumeId_lu(file->dirh_handle->ih_vid), saverr));
 	FDH_REALLYCLOSE(fdP);
-	return code;
+	goto done;
     }
     FDH_CLOSE(fdP);
-    return 0;
+
+ done:
+    if (physerr != NULL)
+	*physerr = saverr;
+    return code;
 
 }
 
@@ -94,19 +110,21 @@ ReallyWrite(DirHandle * file, int block, char *data)
     fdP = IH_OPEN(file->dirh_handle);
     if (fdP == NULL) {
 	ViceLog(0,
-		("ReallyWrite(): open failed device %X inode %s (volume=%u) errno %d\n",
+		("ReallyWrite(): open failed device %X inode %s (volume=%" AFS_VOLID_FMT ") errno %d\n",
 		 file->dirh_handle->ih_dev, PrintInode(stmp,
 						       file->dirh_handle->
-						       ih_ino), file->dirh_handle->ih_vid,errno));
+						       ih_ino),
+		 afs_printable_VolumeId_lu(file->dirh_handle->ih_vid), errno));
 	lpErrno = errno;
 	return 0;
     }
     if ((count = FDH_PWRITE(fdP, data, PAGESIZE, ((afs_foff_t)block) * PAGESIZE)) != PAGESIZE) {
 	ViceLog(0,
-		("ReallyWrite(): write failed device %X inode %s (volume=%u) errno %d\n",
+		("ReallyWrite(): write failed device %X inode %s (volume=%" AFS_VOLID_FMT ") errno %d\n",
 		 file->dirh_handle->ih_dev, PrintInode(stmp,
 						       file->dirh_handle->
-						       ih_ino), file->dirh_handle->ih_vid,errno));
+						       ih_ino),
+		 afs_printable_VolumeId_lu(file->dirh_handle->ih_vid), errno));
 	lpCount = count;
 	lpErrno = errno;
 	FDH_REALLYCLOSE(fdP);
@@ -165,7 +183,7 @@ FidEq(DirHandle * afile, DirHandle * bfile)
 }
 
 int
-FidVolEq(DirHandle * afile, afs_int32 vid)
+FidVolEq(DirHandle * afile, VolumeId vid)
 {
     if (afile->dirh_vid != vid)
 	return 0;
