@@ -123,6 +123,8 @@ fs_stateSave(void)
 	goto done;
     }
 
+    state.mode = FS_STATE_DUMP_MODE;
+
     /* XXX
      * on busy servers, these checks will inevitably fail since stuff drops H_LOCK
      * all over the place (with structs left in inconsistent states) while RPCs to
@@ -221,12 +223,17 @@ fs_stateRestore(void)
 {
     int ret = 0;
     struct fs_dump_state state;
+    struct timeval now;
+    afs_int64 start_ms, end_ms, diff_ms;
 
     /* save and restore need to be atomic wrt other host package operations */
     H_LOCK;
 
     ViceLog(0, ("fs_stateRestore: commencing fileserver state restore\n"));
 
+    opr_Verify(gettimeofday(&now, NULL) == 0);
+    start_ms = now.tv_sec * 1000 + now.tv_usec / 1000;
+
     if (fs_stateAlloc(&state)) {
 	ViceLog(0, ("fs_stateRestore: memory allocation failed\n"));
 	ret = 1;
@@ -292,7 +299,13 @@ fs_stateRestore(void)
 	ViceLog(0, ("fs_stateRestore: fileserver state verification complete\n"));
     }
 
-    ViceLog(0, ("fs_stateRestore: restore was successful\n"));
+    opr_Verify(gettimeofday(&now, NULL) == 0);
+    end_ms = now.tv_sec * 1000 + now.tv_usec / 1000;
+    diff_ms = end_ms - start_ms;
+
+    ViceLog(0, ("fs_stateRestore: restore was successful in %lld ms "
+	    "(%d FEs, %d CBs)\n",
+	    diff_ms, state.cb_hdr->nFEs, state.cb_hdr->nCBs));
 
  done:
     if (state.fd >= 0) {
@@ -328,7 +341,6 @@ fs_stateCreateDump(struct fs_dump_state * state)
     }
 
     state->fd = fd;
-    state->mode = FS_STATE_DUMP_MODE;
     memset(state->hdr, 0, sizeof(struct fs_state_header));
     fs_stateIncEOF(state, sizeof(struct fs_state_header));
 
@@ -769,7 +781,7 @@ fs_stateMapFile(struct fs_dump_state * state, int preserve_flag )
 	flags = PROT_WRITE;
 	break;
     default:
-	ViceLog(0, ("fs_stateMapFile: invalid dump state mode\n"));
+	ViceLog(0, ("fs_stateMapFile: invalid dump state mode %d\n", state->mode));
 	return 1;
     }
 
@@ -1015,13 +1027,11 @@ fs_stateAlloc(struct fs_dump_state * state)
     memset(state, 0, sizeof(struct fs_dump_state));
     state->fd = -1;
     state->fn = (char *)AFSDIR_SERVER_FSSTATE_FILEPATH;
-    state->hdr = malloc(sizeof(struct fs_state_header));
-    state->h_hdr = malloc(sizeof(struct host_state_header));
-    state->cb_hdr = malloc(sizeof(struct callback_state_header));
-    state->cb_timeout_hdr =
-	malloc(sizeof(struct callback_state_timeout_header));
-    state->cb_fehash_hdr =
-	malloc(sizeof(struct callback_state_fehash_header));
+    state->hdr = calloc(1, sizeof(*state->hdr));
+    state->h_hdr = calloc(1, sizeof(*state->h_hdr));
+    state->cb_hdr = calloc(1, sizeof(*state->cb_hdr));
+    state->cb_timeout_hdr = calloc(1, sizeof(*state->cb_timeout_hdr));
+    state->cb_fehash_hdr = calloc(1, sizeof(*state->cb_fehash_hdr));
     if ((state->hdr == NULL) || (state->h_hdr == NULL) || (state->cb_hdr == NULL) ||
 	(state->cb_timeout_hdr == NULL) || (state->cb_fehash_hdr == NULL))
 	ret = 1;
