@@ -16,21 +16,14 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
+#include <roken.h>
 
-#include <stdio.h>
-#ifdef AFS_NT40_ENV
-#include <fcntl.h>
-#include <io.h>
-#else
-#include <sys/param.h>
+#ifdef HAVE_SYS_FILE_H
 #include <sys/file.h>
-#include <sys/time.h>
-#include <unistd.h>
 #endif
-#include <string.h>
-#include <sys/stat.h>
-#include <afs/afs_assert.h>
+
 #include <afs/afsutil.h>
+#include <rx/rx_queue.h>
 
 #include <rx/xdr.h>
 #include "afs/afsint.h"
@@ -53,10 +46,6 @@
 /* forward declarations */
 static int ObliterateRegion(Volume * avp, VnodeClass aclass, StreamHandle_t * afile,
 			    afs_foff_t * aoffset);
-#if 0
-static void PurgeIndex(Volume * vp, VnodeClass class);
-static void PurgeHeader(Volume * vp);
-#endif
 
 static void PurgeIndex_r(Volume * vp, VnodeClass class);
 static void PurgeHeader_r(Volume * vp);
@@ -171,16 +160,6 @@ ObliterateRegion(Volume * avp, VnodeClass aclass, StreamHandle_t * afile,
     return -1;
 }
 
-#if 0
-static void
-PurgeIndex(Volume * vp, VnodeClass class)
-{
-    VOL_LOCK;
-    PurgeIndex_r(vp, class);
-    VOL_UNLOCK;
-}
-#endif
-
 static void
 PurgeIndex_r(Volume * vp, VnodeClass class)
 {
@@ -211,26 +190,19 @@ PurgeIndex_r(Volume * vp, VnodeClass class)
     FDH_CLOSE(fdP);
 }
 
-#if 0
-static void
-PurgeHeader(Volume * vp)
-{
-    VOL_LOCK;
-    PurgeHeader_r(vp);
-    VOL_UNLOCK;
-}
-#endif
-
 static void
 PurgeHeader_r(Volume * vp)
 {
+#ifndef AFS_NAMEI_ENV
+    /* namei opens and closes the given ihandle during IH_DEC, so don't try to
+     * also close it here */
     IH_REALLYCLOSE(V_diskDataHandle(vp));
+#endif
     IH_DEC(V_linkHandle(vp), vp->vnodeIndex[vLarge].handle->ih_ino, V_id(vp));
     IH_DEC(V_linkHandle(vp), vp->vnodeIndex[vSmall].handle->ih_ino, V_id(vp));
     IH_DEC(V_linkHandle(vp), vp->diskDataHandle->ih_ino, V_id(vp));
 #ifdef AFS_NAMEI_ENV
     /* And last, but not least, the link count table itself. */
-    IH_REALLYCLOSE(V_linkHandle(vp));
     IH_DEC(V_linkHandle(vp), vp->linkHandle->ih_ino, V_parentId(vp));
 #endif
 }
