@@ -2,7 +2,7 @@
 #define AFS_SRC_VOL_INTERNAL_H
 
 /* physio.c */
-extern void SetSalvageDirHandle(DirHandle *, afs_int32, Device, Inode,
+extern void SetSalvageDirHandle(DirHandle *, VolumeId, Device, Inode,
                                 int *);
 
 #endif
