@@ -8,33 +8,16 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-#if defined(AFS_NAMEI_ENV) && !defined(AFS_NT40_ENV)
-#include <sys/types.h>
-#include <stdio.h>
-#include <afs/afs_assert.h>
-#ifdef AFS_NT40_ENV
-#include <fcntl.h>
-#include <windows.h>
-#include <winbase.h>
-#include <io.h>
-#include <time.h>
-#else
-#include <sys/file.h>
-#include <sys/time.h>
-#include <unistd.h>
-#endif
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
-#include <errno.h>
-#include <sys/stat.h>
+#include <roken.h>
 
+#ifdef HAVE_SYS_FILE_H
+#include <sys/file.h>
+#endif
+
+#if defined(AFS_NAMEI_ENV) && !defined(AFS_NT40_ENV)
 #include <afs/dir.h>
 #include <rx/xdr.h>
+#include <rx/rx_queue.h>
 #include <afs/afsint.h>
 #include <afs/nfs.h>
 #include <lwp.h>
@@ -45,6 +28,7 @@
 #include <afs/volume.h>
 #include <afs/partition.h>
 #include <afs/viceinode.h>
+
 #include "vol.h"
 #include "volint.h"
 #include "volser.h"
@@ -101,24 +85,22 @@ ExtractVnodes(struct Msg *m, Volume *vol, afs_int32 class,
 
     fdP = IH_OPEN(vol->vnodeIndex[class].handle);
     if (!fdP) {
-	sprintf(m->line, "Couldn't open %s Index of volume %u\n",
-		class ? "small":"large", V_id(vol));
+	sprintf(m->line, "Couldn't open %s Index of volume %" AFS_VOLID_FMT "\n",
+		class ? "small":"large", afs_printable_VolumeId_lu(V_id(vol)));
 	rx_Write(m->call, m->line, strlen(m->line));
 	code = EIO;
 	goto Bad_Extract;
     }
     size = FDH_SIZE(fdP);
-    *list = (struct VnodeExtract *) malloc(size / vcp->diskSize
-					* sizeof(struct VnodeExtract));
+    *list = calloc(size / vcp->diskSize, sizeof(struct VnodeExtract));
     if (!(*list)) {
 	code = ENOMEM;
 	goto Bad_Extract;
     }
-    memset(*list, 0, size / vcp->diskSize * sizeof(struct VnodeExtract));
     stream = FDH_FDOPEN(fdP, "r");
     if (!stream) {
-	sprintf(m->line, "Couldn't stream open %s Index of volume %u\n",
-		class ? "small":"large", V_id(vol));
+	sprintf(m->line, "Couldn't stream open %s Index of volume %" AFS_VOLID_FMT "\n",
+		class ? "small":"large", afs_printable_VolumeId_lu(V_id(vol)));
 	rx_Write(m->call, m->line, strlen(m->line));
 	code = EIO;
 	goto Bad_Extract;
@@ -160,9 +142,9 @@ ExtractVnodes(struct Msg *m, Volume *vol, afs_int32 class,
 	}
     }
     if (m->verbose) {
-	sprintf(m->line, "Volume %u has %u %s vnodes in volume %u\n",
-			V_parentId(vol), *length, class? "small":"large",
-			V_id(vol));
+	sprintf(m->line, "Volume %" AFS_VOLID_FMT " has %u %s vnodes in volume %" AFS_VOLID_FMT "\n",
+		afs_printable_VolumeId_lu(V_parentId(vol)), *length,
+		class? "small":"large", afs_printable_VolumeId_lu(V_id(vol)));
 	rx_Write(m->call, m->line, strlen(m->line));
     }
 
@@ -256,10 +238,10 @@ copyDir(struct Msg *m, IHandle_t *inh, IHandle_t *outh)
 
     infdP = IH_OPEN(inh);
     if (!infdP) {
-	sprintf(m->line, "Couldn't open input directory %u.%u.%u\n",
-		    inh->ih_vid,
-		    (afs_uint32)(inh->ih_ino & NAMEI_VNODEMASK),
-		    (afs_uint32)(inh->ih_ino >> NAMEI_UNIQSHIFT));
+	sprintf(m->line, "Couldn't open input directory %" AFS_VOLID_FMT ".%u.%u\n",
+		afs_printable_VolumeId_lu(inh->ih_vid),
+		(afs_uint32)(inh->ih_ino & NAMEI_VNODEMASK),
+		(afs_uint32)(inh->ih_ino >> NAMEI_UNIQSHIFT));
 	rx_Write(m->call, m->line, strlen(m->line));
 	return EIO;
     }
@@ -274,10 +256,10 @@ copyDir(struct Msg *m, IHandle_t *inh, IHandle_t *outh)
 	FDH_REALLYCLOSE(outfdP);
     outfdP = IH_OPEN(outh);
     if (!outfdP) {
-	sprintf(m->line, "Couldn't open output directory %u.%u.%u\n",
-		    outh->ih_vid,
-		    (afs_uint32)(outh->ih_ino & NAMEI_VNODEMASK),
-		    (afs_uint32)(outh->ih_ino >> NAMEI_UNIQSHIFT));
+	sprintf(m->line, "Couldn't open output directory %" AFS_VOLID_FMT ".%u.%u\n",
+		afs_printable_VolumeId_lu(outh->ih_vid),
+		(afs_uint32)(outh->ih_ino & NAMEI_VNODEMASK),
+		(afs_uint32)(outh->ih_ino >> NAMEI_UNIQSHIFT));
 	rx_Write(m->call, m->line, strlen(m->line));
 	FDH_REALLYCLOSE(infdP);
 	return EIO;
@@ -289,8 +271,8 @@ copyDir(struct Msg *m, IHandle_t *inh, IHandle_t *outh)
 	size_t tlen;
         tlen = size > 2048 ? 2048 : size;
         if (FDH_PREAD(infdP, tbuf, tlen, offset) != tlen) {
-       	    sprintf(m->line, "Couldn't read directory %u.%u.%u\n",
-		    infdP->fd_ih->ih_vid,
+       	    sprintf(m->line, "Couldn't read directory %" AFS_VOLID_FMT ".%u.%u\n",
+		    afs_printable_VolumeId_lu(infdP->fd_ih->ih_vid),
 		    (afs_uint32)(infdP->fd_ih->ih_ino & NAMEI_VNODEMASK),
 		    (afs_uint32)(infdP->fd_ih->ih_ino >> NAMEI_UNIQSHIFT));
 	    rx_Write(m->call, m->line, strlen(m->line));
@@ -300,8 +282,8 @@ copyDir(struct Msg *m, IHandle_t *inh, IHandle_t *outh)
 	    return EIO;
 	}
 	if (FDH_PWRITE(outfdP, tbuf, tlen, offset) != tlen) {
-	    sprintf(m->line, "Couldn't write directory %u.%u.%u\n",
-		    outfdP->fd_ih->ih_vid,
+	    sprintf(m->line, "Couldn't write directory %" AFS_VOLID_FMT ".%u.%u\n",
+		    afs_printable_VolumeId_lu(outfdP->fd_ih->ih_vid),
 		    (afs_uint32)(outfdP->fd_ih->ih_ino & NAMEI_VNODEMASK),
 		    (afs_uint32)(outfdP->fd_ih->ih_ino >> NAMEI_UNIQSHIFT));
 	    rx_Write(m->call, m->line, strlen(m->line));
@@ -332,25 +314,23 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
     FdHandle_t *newfdP = 0;
     struct VnodeClassInfo *vcp = &VnodeClassInfo[class];
     struct VnodeExtract *e;
-    afs_sfsize_t size;
     afs_uint64 offset;
     Inode ino, newino;
 
     fdP = IH_OPEN(vol->vnodeIndex[class].handle);
     if (!fdP) {
-	Log("Couldn't open %s Index of volume %u\n",
-		class ? "small":"large", V_id(vol));
+	Log("Couldn't open %s Index of volume %" AFS_VOLID_FMT "\n",
+	    class ? "small":"large", afs_printable_VolumeId_lu(V_id(vol)));
 	code = EIO;
 	goto Bad_Copy;
     }
     newfdP = IH_OPEN(newvol->vnodeIndex[class].handle);
     if (!newfdP) {
-	Log("Couldn't open %s Index of volume %u\n",
-		class ? "small":"large", V_id(newvol));
+	Log("Couldn't open %s Index of volume %" AFS_VOLID_FMT "\n",
+	    class ? "small":"large", afs_printable_VolumeId_lu(V_id(newvol)));
 	code = EIO;
 	goto Bad_Copy;
     }
-    size = FDH_SIZE(fdP);
 
     for (i=0; i<length; i++) {
 	e = &list[i];
@@ -358,9 +338,9 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 	    afs_uint64 size;
 	    offset = (e->vN + 1 - class) << (vcp->logSize -1);
 	    if (FDH_PREAD(fdP, vnode, vcp->diskSize, offset) != vcp->diskSize) {
-		Log("Couldn't read in %s Index of volume %u at offset %"
-		    AFS_UINT64_FMT "\n", class ? "small":"large",
-		    V_id(vol), offset);
+		Log("Couldn't read in %s Index of volume %" AFS_VOLID_FMT " at offset %llu\n",
+		    class ? "small":"large",
+		    afs_printable_VolumeId_lu(V_id(vol)), offset);
 		code = EIO;
 		goto Bad_Copy;
 	    }
@@ -390,13 +370,13 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 		VNDISK_SET_INO(vnode, newino);
 		vnode->cloned = 0;
 	        if (FDH_PWRITE(fdP, vnode, vcp->diskSize, offset) != vcp->diskSize) {
-		    Log("Couldn't write in %s Index of volume %u at offset %"
-			AFS_UINT64_FMT "\n", class ? "small":"large",
-			V_id(vol), offset);
+		    Log("Couldn't write in %s Index of volume %" AFS_VOLID_FMT " at offset %llu\n",
+			class ? "small":"large", afs_printable_VolumeId_lu(V_id(vol)), offset);
 		    code = EIO;
 		    goto Bad_Copy;
 	        }
-	        memcpy(parVnode, vnode, sizeof(struct VnodeDiskObject));
+		if (parVnode != NULL)
+		    memcpy(parVnode, vnode, sizeof(struct VnodeDiskObject));
 	    }
 	    if (e->flag & NEEDED && e->vN != where) {
 	        VNDISK_GET_LEN(size, vnode);
@@ -404,7 +384,7 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 	        ino = VNDISK_GET_INO(vnode);
 	        if (ino) {
 		    IHandle_t *h, *newh;
-		    Inode nearInode AFS_UNUSED;
+		    Inode AFS_UNUSED nearInode;
 #if defined(NEARINODE_HINT) && !defined(AFS_NAMEI_ENV)
 		    V_pref(vol,nearInode)
 #endif
@@ -417,8 +397,8 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 			        e->vN, vnode->uniquifier,
 			        vnode->dataVersion);
 	            if (!VALID_INO(newino)) {
-		        Log("IH_CREATE failed for %u.%u.%u\n",
-			    V_id(newvol), e->vN, vnode->uniquifier);
+		        Log("IH_CREATE failed for %" AFS_VOLID_FMT ".%u.%u\n",
+			    afs_printable_VolumeId_lu(V_id(newvol)), e->vN, vnode->uniquifier);
 		        code = EIO;
 		        goto Bad_Copy;
 	            }
@@ -437,9 +417,8 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 		    vnode->parent = 1; /* in new root-directory */
 		vnode->cloned = 0;
 	        if (FDH_PWRITE(newfdP, vnode, vcp->diskSize, offset) != vcp->diskSize) {
-		    Log("Couldn't write in %s Index of volume %u to offset %"
-			AFS_UINT64_FMT "\n", class ? "small":"large",
-			V_id(newvol), offset);
+		    Log("Couldn't write in %s Index of volume %" AFS_VOLID_FMT " to offset %llu\n",
+			class ? "small":"large", afs_printable_VolumeId_lu(V_id(newvol)), offset);
 		    code = EIO;
 		    goto Bad_Copy;
 	        }
@@ -453,19 +432,19 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 	IHandle_t *h, *newh;
         char buf2[SIZEOF_LARGEDISKVNODE];
         struct VnodeDiskObject *vnode2 = (struct VnodeDiskObject *)&buf2;
-	afs_uint64 newoffset;
+	afs_uint64 newoffset, size;
 
 	newoffset = vcp->diskSize;
 	if (FDH_PREAD(newfdP, vnode2, vcp->diskSize, newoffset) != vcp->diskSize) {
-	    Log("splitvolume: couldn't read in large Index of new volume %u at offset %u\n",
-		    V_id(newvol), vcp->diskSize);
+	    Log("splitvolume: couldn't read in large Index of new volume %" AFS_VOLID_FMT " at offset %u\n",
+		afs_printable_VolumeId_lu(V_id(newvol)), vcp->diskSize);
 	    code = EIO;
 	    goto Bad_Copy;
   	}
 	offset = (where + 1 - class) << (vcp->logSize -1);
 	if (FDH_PREAD(fdP, vnode, vcp->diskSize, offset) != vcp->diskSize) {
-	    Log("Couldn't read in large Index of old volume %u at offset %"
-		AFS_UINT64_FMT "\n", V_id(vol), offset);
+	    Log("Couldn't read in large Index of old volume %" AFS_VOLID_FMT " at offset %llu\n",
+		afs_printable_VolumeId_lu(V_id(vol)), offset);
 	    code = EIO;
 	    goto Bad_Copy;
 	}
@@ -478,8 +457,9 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 	code = copyDir(m, h, newh);
  	if (code) {
 	    Log("splitvolume: copyDir failed for new root from "
-		"%u.%u.%u to %u.1.1\n",
-	        V_id(vol), where, vnode->uniquifier, V_id(newvol));
+		"%" AFS_VOLID_FMT ".%u.%u to %" AFS_VOLID_FMT ".1.1\n",
+	        afs_printable_VolumeId_lu(V_id(vol)), where, vnode->uniquifier,
+		afs_printable_VolumeId_lu(V_id(newvol)));
 	    code = EIO;
 	    goto Bad_Copy;
 	}
@@ -489,8 +469,8 @@ afs_int32 copyVnodes(struct Msg *m, Volume *vol, Volume *newvol,
 	vnode->parent = vnode2->parent;
 	vnode->serverModifyTime = vnode2->serverModifyTime;
 	if (FDH_PWRITE(newfdP, vnode, vcp->diskSize, newoffset) != vcp->diskSize) {
-	    Log("splitvolume: couldn't write in large Index of %u at offset %u\n",
-		    V_id(newvol), vcp->diskSize);
+	    Log("splitvolume: couldn't write in large Index of %" AFS_VOLID_FMT " at offset %u\n",
+		afs_printable_VolumeId_lu(V_id(newvol)), vcp->diskSize);
 	    code = EIO;
 	}
     }
@@ -513,7 +493,7 @@ findName(Volume *vol, struct VnodeDiskObject *vd, afs_uint32 vN,
     ino = VNDISK_GET_INO(vd);
     SetSalvageDirHandle(&dir, V_id(vol), V_device(vol), ino);
 
-    code = InverseLookup(&dir, vN, un, name, length);
+    code = afs_dir_InverseLookup(&dir, vN, un, name, length);
     FidZap(&dir);
     return code;
 }
@@ -538,13 +518,13 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
     AFSFid fid;
     struct timeval now;
     afs_uint32 newvN;
-    char symlink[32];
+    char symlink[VNAMESIZE + 1];
     ssize_t rc;
 
     FT_GetTimeOfDay(&now, 0);
     fdP = IH_OPEN(vol->vnodeIndex[vSmall].handle);
     if (!fdP) {
-	Log("split volume: error opening small vnode index of %u\n", V_id(vol));
+	Log("split volume: error opening small vnode index of %" AFS_VOLID_FMT "\n", afs_printable_VolumeId_lu(V_id(vol)));
 	return EIO;
     }
     offset = vcp->diskSize;
@@ -552,7 +532,7 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
 	rc = FDH_PREAD(fdP, &vnode, vcp->diskSize, offset);
 	if (rc != vcp->diskSize) {
 	    if (rc < 0) {
-	        Log("split volume: error reading small vnode index of %u\n", V_id(vol));
+	        Log("split volume: error reading small vnode index of %" AFS_VOLID_FMT "\n", afs_printable_VolumeId_lu(V_id(vol)));
 	        return EIO;
 	     }
 	     if (rc == 0)
@@ -589,15 +569,15 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
     IH_INIT(h, V_device(vol), V_parentId(vol), newino);
     fdP2 = IH_OPEN(h);
     if (!fdP2) {
-	Log("split volume: couldn't open inode for mountpoint %u.%u.%u\n",
-		V_id(vol), newvN, vnode.uniquifier);
+	Log("split volume: couldn't open inode for mountpoint %" AFS_VOLID_FMT ".%u.%u\n",
+	    afs_printable_VolumeId_lu(V_id(vol)), newvN, vnode.uniquifier);
 	return EIO;
     }
     sprintf(symlink, "#%s", V_name(newvol));
     size = strlen(symlink) + 1;
     if (FDH_PWRITE(fdP2, symlink, size, 0) != size) {
-	Log("split volume: couldn't write mountpoint %u.%u.%u\n",
-		V_id(vol), newvN, vnode.uniquifier);
+	Log("split volume: couldn't write mountpoint %" AFS_VOLID_FMT ".%u.%u\n",
+	    afs_printable_VolumeId_lu(V_id(vol)), newvN, vnode.uniquifier);
 	return EIO;
     }
     FDH_REALLYCLOSE(fdP2);
@@ -608,8 +588,8 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
     vnode.vnodeMagic = SMALLVNODEMAGIC;
 #endif
     if (FDH_PWRITE(fdP, &vnode, vcp->diskSize, offset) != vcp->diskSize) {
-	Log("split volume: couldn't write vnode for mountpoint %u.%u.%u\n",
-		V_id(vol), newvN, vnode.uniquifier);
+	Log("split volume: couldn't write vnode for mountpoint %" AFS_VOLID_FMT ".%u.%u\n",
+	    afs_printable_VolumeId_lu(V_id(vol)), newvN, vnode.uniquifier);
 	return EIO;
     }
     FDH_REALLYCLOSE(fdP);
@@ -625,13 +605,13 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
     ino = VNDISK_GET_INO(parent);
     SetSalvageDirHandle(&dir, V_id(vol), V_device(vol), ino);
 
-    code = Delete(&dir, name);
+    code = afs_dir_Delete(&dir, name);
     if (code) {
-	Log("splitvolume: couldn't delete directory entry for %s in %u.%u.%u, code = %d\n",
-			name, V_id(vol), vN, parent->uniquifier, code);
+	Log("splitvolume: couldn't delete directory entry for %s in %" AFS_VOLID_FMT ".%u.%u, code = %d\n",
+	    name, afs_printable_VolumeId_lu(V_id(vol)), vN, parent->uniquifier, code);
 	return code;
     }
-    code = Create(&dir, name, &fid);
+    code = afs_dir_Create(&dir, name, &fid);
     FidZap(&dir);
 
     /* Make sure the directory file doesn't remain open */
@@ -647,8 +627,8 @@ createMountpoint(Volume *vol, Volume *newvol, struct VnodeDiskObject *parent,
     offset = (vN + 1 - class) << (vcp->logSize -1);
     parent->dataVersion++;
     if (FDH_PWRITE(fdP, parent, vcp->diskSize, offset) != vcp->diskSize) {
-	Log("split volume: couldn't write vnode for parent directory %u.%u.%u\n",
-		V_id(vol), vN, parent->uniquifier);
+	Log("split volume: couldn't write vnode for parent directory %" AFS_VOLID_FMT ".%u.%u\n",
+	    afs_printable_VolumeId_lu(V_id(vol)), vN, parent->uniquifier);
 	return EIO;
     }
     FDH_REALLYCLOSE(fdP);
@@ -672,8 +652,8 @@ deleteVnodes(Volume *vol, afs_int32 class,
 
     fdP = IH_OPEN(vol->vnodeIndex[class].handle);
     if (!fdP) {
-	Log("Couldn't open %s Index of volume %u\n",
-		class ? "small":"large", V_id(vol));
+	Log("Couldn't open %s Index of volume %" AFS_VOLID_FMT "\n",
+	    class ? "small":"large", afs_printable_VolumeId_lu(V_id(vol)));
 	code = EIO;
 	goto Bad_Delete;
     }
@@ -683,9 +663,8 @@ deleteVnodes(Volume *vol, afs_int32 class,
 	if (e->flag & NEEDED) {
 	    offset = (e->vN + 1 - class) << (vcp->logSize -1);
 	    if (FDH_PREAD(fdP, vnode, vcp->diskSize, offset) != vcp->diskSize) {
-		Log("Couldn't read in %s Index of volume %u at offset %"
-		    AFS_UINT64_FMT "\n", class ? "small":"large", V_id(vol),
-		    offset);
+		Log("Couldn't read in %s Index of volume %" AFS_VOLID_FMT " at offset %llu\n",
+		    class ? "small":"large", afs_printable_VolumeId_lu(V_id(vol)), offset);
 		code = EIO;
 		goto Bad_Delete;
 	    }
@@ -704,9 +683,8 @@ deleteVnodes(Volume *vol, afs_int32 class,
 	    memset(vnode, 0, vcp->diskSize);
 	    vnode->type = vNull;
 	    if (FDH_PWRITE(fdP, vnode, vcp->diskSize, offset) != vcp->diskSize) {
-	           Log("Couldn't write in %s Index of volume %u to offset %"
-		       AFS_UINT64_FMT "\n", class ? "small":"large",
-		       V_id(vol), offset);
+	           Log("Couldn't write in %s Index of volume %" AFS_VOLID_FMT " to offset %llu\n",
+		       class ? "small":"large", afs_printable_VolumeId_lu(V_id(vol)), offset);
 	    }
         }
     }
@@ -734,8 +712,7 @@ split_volume(struct rx_call *call, Volume *vol, Volume *newvol,
     afs_uint32 parent;
     struct Msg *m;
 
-    m = (struct Msg *) malloc(sizeof(struct Msg));
-    memset(m, 0, sizeof(struct Msg));
+    m = calloc(1, sizeof(struct Msg));
     m->call = call;
     m->verbose = verbose;
 
@@ -755,23 +732,23 @@ split_volume(struct rx_call *call, Volume *vol, Volume *newvol,
 			&parent, parVnode);
     if (code) {
 	sprintf(m->line,
-		"ExtractVnodes failed for %u for directories with code %d\n",
-	        V_id(vol), code);
+		"ExtractVnodes failed for %" AFS_VOLID_FMT " for directories with code %d\n",
+	        afs_printable_VolumeId_lu(V_id(vol)), code);
 	rx_Write(m->call, m->line, strlen(m->line));
 	return code;
     }
 
     if (verbose) {
-	sprintf(m->line, "2nd step: look for name of vnode %u in directory %u.%u.%u\n",
-		where, V_id(vol), parent, parVnode->uniquifier);
+	sprintf(m->line, "2nd step: look for name of vnode %u in directory %" AFS_VOLID_FMT ".%u.%u\n",
+		where, afs_printable_VolumeId_lu(V_id(vol)), parent, parVnode->uniquifier);
 	rx_Write(m->call, m->line, strlen(m->line));
     }
     code = findName(vol, parVnode, where, rootVnode->uniquifier,
                     name,  sizeof(name));
     if (code) {
 	sprintf(m->line,
-		"splitvolume: could'nt find name of %u in directory %u.%u.%u.\n",
-		where, V_id(vol), parent, parVnode->uniquifier);
+		"splitvolume: could'nt find name of %u in directory %" AFS_VOLID_FMT ".%u.%u.\n",
+		where, afs_printable_VolumeId_lu(V_id(vol)), parent, parVnode->uniquifier);
 	rx_Write(m->call, m->line, strlen(m->line));
 	return code;
     }
@@ -800,8 +777,8 @@ split_volume(struct rx_call *call, Volume *vol, Volume *newvol,
     code = ExtractVnodes(m, vol, vSmall, &fileList, &fl, where, 0, 0, 0);
     if (code) {
 	sprintf(m->line,
-		"ExtractVnodes failed for %u for files with code %d\n",
-		V_id(vol), code);
+		"ExtractVnodes failed for %" AFS_VOLID_FMT " for files with code %d\n",
+		afs_printable_VolumeId_lu(V_id(vol)), code);
 	rx_Write(m->call, m->line, strlen(m->line));
 	return code;
     }
